@@ -1,4 +1,4 @@
-## Copyright 2009-2012 Luc Saffre
+## Copyright 2009-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -27,16 +27,18 @@ import copy
 
 from django.db import models
 from django.conf import settings
+from django.utils.translation import ugettext_lazy as _
 
 import lino
-from lino.ui import base
+#~ from lino.ui import base
 
 #~ from lino.ui.base import Handled
 from lino.core import fields
 from lino.core import actions
 from lino.core import layouts
 #~ from lino.core import changes
-from lino.core.modeltools import resolve_model
+from lino.core.dbutils import resolve_model
+from lino.core.requests import ActionRequest
 from lino.utils import curry, AttrDict
 #~ from lino.core import perms
 from lino.utils import jsgen
@@ -50,7 +52,7 @@ actors_list = None
 ACTOR_SEP = '.'
 
 
-MODULES = AttrDict()
+#~ MODULES = AttrDict()
   
 def discover():
     global actor_classes
@@ -68,7 +70,7 @@ def discover():
 
 def register_actor(a):
     #~ logger.debug("register_actor %s",a)
-    old = MODULES.define(a.app_label,a.__name__,a)
+    old = settings.SITE.modules.define(a.app_label,a.__name__,a)
     #~ old = actors_dict.get(a.actor_id,None)
     if old is not None:
         #~ logger.info("20121023 register_actor %s : %r replaced by %r",a,old,a)
@@ -86,6 +88,13 @@ def register_actor(a):
     
     
     
+def get_default_required(**kw):
+    #~ if not kw.has_key('auth'):
+        #~ kw.update(auth=True)
+    if settings.SITE.user_model is not None:
+        kw.setdefault('auth',True)
+    return kw
+    
     
     
 class BoundAction(object):
@@ -269,6 +278,7 @@ class Actor(actions.Parametrizable):
     
     _layout_class = layouts.ParamsLayout
     
+    hidden_elements = frozenset()
     
     app_label = None
     """
@@ -300,9 +310,9 @@ class Actor(actions.Parametrizable):
     """
     
     #~ required = dict()
-    #~ required = dd.required()
+    required = get_default_required()
     
-    required = dict(auth=True) # 20121116
+    #~ required = dict(auth=True) # 20121116
     
     #~ create_required = dict()
     update_required = dict()
@@ -331,7 +341,8 @@ class Actor(actions.Parametrizable):
     """
     Set this explicitly to True or False to make the 
     Actor per se editable or not.
-    Otherwise it will be set to `False` if the Actor is a Table has a `get_data_rows` method.
+    Otherwise it will be set to `False` if the Actor 
+    is a Table and has a `get_data_rows` method.
     
     The :class:`lino.models.Changes` table is an example where this is being used: 
     nobody should ever edit something in the table of Changes. 
@@ -366,35 +377,33 @@ class Actor(actions.Parametrizable):
     
     
     
-    #~ disabled_fields = None
-    """
-    Return a list of field names that should not be editable 
-    for the specified `obj` and `request`.
-    
-    If defined in the Table, this must be a class method that accepts 
-    two arguments `obj` and `ar` (an `ActionRequest`)::
-    
-      @classmethod
-      def disabled_fields(cls,obj,ar):
-          ...
-          return []
-          
-    
-    If not defined in the Table, Lino will look whether 
-    the Table's model has a `disabled_fields` method 
-    and install a wrapper to this model method. 
-    When defined on the model, is must be an *instance* 
-    method
-    
-      def disabled_fields(self,ar):
-          ...
-          return []
-    
-    See also :doc:`/tickets/2`.
-    """
-    
     @classmethod
     def disabled_fields(cls,obj,ar):
+        """
+        Return a list of field names that should not be editable 
+        for the specified `obj` and `request`.
+        
+        If defined in the Table, this must be a class method that accepts 
+        two arguments `obj` and `ar` (an `ActionRequest`)::
+        
+          @classmethod
+          def disabled_fields(cls,obj,ar):
+              ...
+              return []
+              
+        
+        If not defined in the Table, Lino will look whether 
+        the Table's model has a `disabled_fields` method 
+        and install a wrapper to this model method. 
+        When defined on the model, is must be an *instance* 
+        method
+        
+          def disabled_fields(self,ar):
+              ...
+              return []
+        
+        See also :doc:`/tickets/2`.
+        """
         return []
     
     
@@ -412,7 +421,7 @@ class Actor(actions.Parametrizable):
     hide_window_title = False
     """
     This is set to `True` in home pages
-    (e.g. :class:`lino.apps.pcsw.models.Home`).
+    (e.g. :class:`lino_welfare.modlib.pcsw.models.Home`).
     """
     
     allow_create = True
@@ -420,10 +429,10 @@ class Actor(actions.Parametrizable):
     If this is False, then then Actor won't have neither create_action nor insert_action.
     """
 
-    #~ has_navigator = True
     hide_top_toolbar = False
     """
-    Whether a Detail Window should have navigation buttons, a "New" and a "Delete" buttons.
+    Whether a Detail Window should have navigation buttons, 
+    a "New" and a "Delete" buttons.
     In ExtJS UI also influences the title of a Detail Window to specify only 
     the current element without prefixing the Tables's title.
     
@@ -499,7 +508,7 @@ class Actor(actions.Parametrizable):
     get_handle_name = None
     """
     Most actors use the same UI handle for each request. 
-    But debts.PrintEntriesByBudget overrides this to 
+    But e.g. debts.PrintEntriesByBudget overrides this to 
     implement dynamic columns depending on it's master_instance.
     """
         
@@ -524,6 +533,18 @@ class Actor(actions.Parametrizable):
         return False
         
             
+    @classmethod
+    def has_handle(self,ui):
+        if ui is None:
+            hname = '_lino_console_handler'
+        else:
+            hname = ui._handle_attr_name
+        return self.__dict__.get(hname,False)
+        
+    @classmethod
+    def on_analyze(self,site):
+        pass
+        
     @classmethod
     def get_handle(self,ui):
         #~ assert ar is None or isinstance(ui,UI), \
@@ -571,7 +592,7 @@ class Actor(actions.Parametrizable):
             #~ print "20120524",cls, "class_init()", cls.__bases__
         #~ 20121008 cls.default_action = cls.get_default_action()
         
-        classDict = cls.__dict__
+        #~ classDict = cls.__dict__
         
         #~ dt = classDict.get('detail_template',None)
         dt = getattr(cls,'detail_template',None)
@@ -587,7 +608,7 @@ class Actor(actions.Parametrizable):
             if isinstance(dl,basestring):
                 cls.detail_layout = layouts.FormLayout(dl,cls)
             elif dl._datasource is None:
-                dl._datasource = cls
+                dl.set_datasource(cls)
                 cls.detail_layout = dl
             elif not issubclass(cls,dl._datasource):
                 raise Exception("Cannot reuse %r detail_layout for %r" % (dl._datasource,cls))
@@ -607,7 +628,7 @@ class Actor(actions.Parametrizable):
             if isinstance(dl,basestring):
                 cls.insert_layout = layouts.FormLayout(dl,cls)
             elif dl._datasource is None:
-                dl._datasource = cls
+                dl.set_datasource(cls)
                 cls.insert_layout = dl
             elif not issubclass(cls,dl._datasource):
                 raise Exception("Cannot reuse %r insert_layout for %r" % (dl._datasource,cls))
@@ -629,10 +650,9 @@ class Actor(actions.Parametrizable):
                         if cls.__dict__.get(k,None) is None:
                             #~ logger.info("20120628 %s.%s copied from %s",cls,k,b)
                             #~ label = v.label
-                            v = copy.deepcopy(v)
-                            #~ v.label = label
-                            #~ v = copy.copy(v)
-                            v.name = None
+                            #~ 20130121 : removed two following lines 
+                            #~ v = copy.deepcopy(v)
+                            #~ v.name = None
                             setattr(cls,k,v)
                             #~ cls.define_action(k,v)
                             #~ if b is EmptyTable:
@@ -651,6 +671,14 @@ class Actor(actions.Parametrizable):
         return self.__name__
                         
         
+    @classmethod
+    def hide_elements(self,*names):
+        for name in names:
+            if self.get_data_elem(name) is None:
+                raise Exception("%s has no element '%s'" % self,name)
+        self.hidden_elements = self.hidden_elements | set(names)
+            
+        
     @classmethod
     def add_view_requirements(cls,**kw):
         return actions.add_requirements(cls,**kw)
@@ -775,15 +803,24 @@ class Actor(actions.Parametrizable):
 
     @classmethod
     def get_workflow_actions(self,ar,obj):
+        """
+        Return the actions to be displayed in a `workflow_buttons` field.
+        """
         state = self.get_row_state(obj)
+        #~ logger.info("20130114 get_workflow_actions() for %s (state is %s)",
+            #~ ar.bound_action.action,state)
         #~ u = ar.get_user()
-        for ba in self.get_actions(ar.bound_action.action):
+        
+        #~ for ba in self.get_actions(ar.bound_action.action):
+        for ba in self.get_actions():
             if ba.action.show_in_workflow:
                 #~ if obj.get_row_permission(ar,state,ba):
                 if self.get_row_permission(obj,ar,state,ba):
                     yield ba
                 #~ else:
-                    #~ logger.info('20121020 no permission for [%s]', unicode(ba.action.label))
+                    #~ logger.info('20130114 %s has no permission for [%s]', ar.get_user(),unicode(ba.action.label))
+            #~ else:
+                #~ logger.info('20130114 [%s] has not show_in_workflow', unicode(ba.action.label))
         
     @classmethod
     def get_label(self):
@@ -814,6 +851,12 @@ class Actor(actions.Parametrizable):
         pass
         
         
+    @classmethod
+    def get_param_elem(self,name):
+        # same as in Action, but here it is a class method
+        if self.parameters:
+            return self.parameters.get(name,None)
+        return None
         
             
     @classmethod
@@ -843,6 +886,14 @@ class Actor(actions.Parametrizable):
     def override_column_headers(self,ar):
         return {}
         
+    @classmethod
+    def get_sum_text(self,ar):
+        """
+        Return the text to display on the totals row.
+        """
+        return unicode(_("Total (%d rows)") % ar.get_total_count())
+        
+        
     #~ @classmethod
     #~ def get_detail(self):
         #~ return self.detail_layout
@@ -924,8 +975,9 @@ class Actor(actions.Parametrizable):
 
     @classmethod
     def add_virtual_field(cls,name,vf):
-        if cls.virtual_fields.has_key(name):
-            raise Exception("Duplicate add_virtual_field() %s.%s" % (cls,name))
+        if False: # disabled because UsersWithClients defines virtual fields on connection_created
+            if cls.virtual_fields.has_key(name):
+                raise Exception("Duplicate add_virtual_field() %s.%s" % (cls,name))
         cls.virtual_fields[name] = vf
         #~ vf.lino_resolve_type(cls,name)
         vf.name = name
@@ -951,7 +1003,7 @@ class Actor(actions.Parametrizable):
             else:
                 logger.warning("%s.setup() called recursively" % self)
                 return False
-        #~ logger.debug("Actor.setup() %s", self)
+        #~ logger.info("20130219 Actor.after_site_setup() %s", self)
         self._setup_doing = True
         
         if not self.is_abstract():
@@ -974,11 +1026,12 @@ class Actor(actions.Parametrizable):
         
         
     @classmethod
-    def get_url_action(self,name):
+    def get_action_by_name(self,name):
         return self._actions_dict.get(name,None)
         #~ a = self._actions_dict.get(name,None)
         #~ if a is not None:
             #~ return actions.BoundAction(self,a)
+    get_url_action = get_action_by_name
         
     @classmethod
     def get_url_action_names(self):
@@ -1015,16 +1068,16 @@ class Actor(actions.Parametrizable):
         s = name.split('.')
         if len(s) == 1:
             #~ app_label = model._meta.app_label
-            rpt = settings.LINO.modules[self.app_label].get(name,None)
+            rpt = settings.SITE.modules[self.app_label].get(name,None)
         elif len(s) == 2:
             # 20121113
             #~ app = resolve_app(s[0])
             #~ rpt = getattr(app,s[1],None)
-            m = settings.LINO.modules.get(s[0],None)
+            m = settings.SITE.modules.get(s[0],None)
             if m is None:
                 return fields.DummyField()
             return m.get(s[1],None)
-            #~ rpt = settings.LINO.modules[s[0]].get(s[1],None)
+            #~ rpt = settings.SITE.modules[s[0]].get(s[1],None)
         else:
             raise Exception("Invalid data element name %r" % name)
         if rpt is not None: 
@@ -1074,7 +1127,7 @@ class Actor(actions.Parametrizable):
               
     @classmethod
     def request(self,ui=None,request=None,action=None,**kw):
-        return actions.ActionRequest(ui,self,request,action,**kw)
+        return ActionRequest(ui,self,request,action,**kw)
 
         
     @classmethod
@@ -1099,9 +1152,10 @@ class Actor(actions.Parametrizable):
         """
         Shortcut which calls :meth:`lino.Lino.startup`, 
         creates an action request for this actor 
-        and calls its :meth:`ActionRequest.to_rst` method.
+        and calls its :meth:`lino.core.actions.ActionRequest.to_rst` 
+        method.
         """
-        settings.LINO.startup()
+        #~ settings.SITE.startup()
         return self.request(**kw).to_rst(column_names)
         
     @classmethod
@@ -1111,17 +1165,6 @@ class Actor(actions.Parametrizable):
         creates an action request for this actor 
         and calls its :meth:`ActionRequest.table2xhtml` method.
         """
-        settings.LINO.startup()
-        return self.request(**kw).table2xhtml()
+        settings.SITE.startup()
+        return xghtml.E.tostring(self.request(**kw).table2xhtml())
         
-
-#~ def workflow(target_state,**kw):
-    #~ """
-    #~ Decorator to define workflow actions.
-    #~ """
-    #~ req = kw.pop('required',{})
-    #~ def decorator(fn):
-        #~ a = ChangeStateAction(target_state,req,**kw)
-        #~ a.run = fn
-        #~ return a
-    #~ return decorator
