@@ -60,9 +60,8 @@ import lino
 #~ from lino import layouts
 from lino.core import fields
 from lino.core import actions
-from lino.utils import babel
 from lino.core.model import Model
-from lino.core.modeltools import obj2str
+from djangosite.dbutils import obj2str
 from lino.utils.config import load_config_files, Configured
 #~ from lino.core import datalinks
 #~ from lino.core import boolean_texts
@@ -73,9 +72,10 @@ from lino.core import frames
 
 #~ from lino.ui import requests as ext_requests
 
-from lino.core.modeltools import resolve_model, resolve_field, full_model_name, get_field, UnresolvedModel
+from lino.core.dbutils import full_model_name
+from lino.core.dbutils import resolve_model, resolve_field, get_field, UnresolvedModel
 #~ from lino.utils.config import LOCAL_CONFIG_DIR
-from lino.core.modeltools import get_model_report
+from lino.core.dbutils import get_model_report
 from lino.core.tables import AbstractTable, TableRequest, VirtualTable
 #~ from lino.core.tables import GridEdit #, ComputedColumn
 
@@ -87,7 +87,7 @@ from lino.core.tables import AbstractTable, TableRequest, VirtualTable
 def unused_parse_js_date(s,name):
     #~ v = dateparser.parse(s)
     #~ v = dateparser.parse(s,fuzzy=True)
-    return datetime.date(*settings.LINO.parse_date(s))
+    return datetime.date(*settings.SITE.parse_date(s))
     #~ print "parse_js_date %s : %r -> %s" % (name,s,v)
     #~ return v
     
@@ -242,7 +242,7 @@ def add_gridfilters(qs,gridfilters):
             kw[field.name+"__equals"] = flt['value']
             q = q & models.Q(**kw)
         elif flttype == 'date':
-            v = datetime.date(*settings.LINO.parse_date(flt['value']))
+            v = datetime.date(*settings.SITE.parse_date(flt['value']))
             #~ v = parse_js_date(flt['value'],field.name)
             cmp = str(flt['comparison'])
             if cmp == 'eq': cmp = 'exact'
@@ -764,10 +764,12 @@ class Table(AbstractTable):
         to be deleted by action request `ar`,
         or a string with a message explaining why, if not.
         """
+        #~ logger.info("20130225 dbtables.disable_delete")
         if self.delete_action is None:
             return "No delete_action"
         if not self.get_row_permission(obj,ar,self.get_row_state(obj),self.delete_action):
-        #~ if not obj.get_row_permission(self.delete_action,ar.get_user()):
+            #~ print "20130222 ar is %r" % ar
+            #~ logger.info("20130225 dbtables.disable_delete no permission")
             return _("You have no permission to delete this row.")
         return obj.disable_delete(ar)
         
@@ -963,8 +965,8 @@ def table_factory(model):
     #~ actor lookup needs it. Otherwise we'd get a 
     #~ `'module' object has no attribute 'DataControlListingTable'` error.
     
-    #~ We cannot simply do ``settings.LINO.modules.define(app_label,name,cls)``
-    #~ because this code is executed when `settings.LINO.modules` doesn't yet exist.
+    #~ We cannot simply do ``settings.SITE.modules.define(app_label,name,cls)``
+    #~ because this code is executed when `settings.SITE.modules` doesn't yet exist.
     #~ """
     
     #~ m = import_module(model.__module__)
