@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2008-2012 Luc Saffre
+## Copyright 2008-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -31,13 +31,13 @@ from decimal import Decimal
 import logging
 logger = logging.getLogger(__name__)
 
-from lino.core.modeltools import full_model_name
-from lino.core.modeltools import obj2str
-from lino.core.modeltools import resolve_field
-from lino.core.modeltools import resolve_model
+from djangosite.dbutils import full_model_name
+from djangosite.dbutils import obj2str
+from lino.core.dbutils import resolve_field
+from lino.core.dbutils import resolve_model, UnresolvedModel
+#~ from lino.core.dbutils import is_installed_model_spec
 
 #~ from lino.utils import choosers
-#~ from lino.utils import choicelists
 from lino.utils import IncompleteDate, d2iso
 #~ from lino.utils.quantities import Duration
 from lino.utils import quantities 
@@ -67,30 +67,60 @@ class RichTextField(models.TextField):
         
     def set_format(self,fmt):
         self.textfield_format = fmt
-    
+
+
+
+from north.babel import contribute_to_class
+
+class BabelTextField(RichTextField):
+    """
+    Define a variable number of clones of the "master" field, 
+    one for each language .
+    """
+    def contribute_to_class(self, cls, name):
+        super(BabelTextField,self).contribute_to_class(cls, name)
+        contribute_to_class(self,cls,RichTextField,
+            format=self.textfield_format)
+
+
   
-class PercentageField(models.SmallIntegerField):
-    """
-    Deserves more documentation.
-    """
-    def __init__(self, *args, **kw):
-        defaults = dict(
-            max_length=3,
-            )
-        defaults.update(kw)
-        models.SmallIntegerField.__init__(self,*args, **defaults)
-  
-#~ class MonthField(models.CharField):
-class MonthField(models.DateField):
-    """
-    Deserves more documentation.
-    """
-    def __init__(self, *args, **kw):
+#~ class PercentageField(models.SmallIntegerField):
+    #~ """
+    #~ Deserves more documentation.
+    #~ """
+    #~ def __init__(self, *args, **kw):
         #~ defaults = dict(
-            #~ max_length=10,
+            #~ max_length=3,
             #~ )
         #~ defaults.update(kw)
-        #~ models.CharField.__init__(self,*args, **defaults)
+        #~ models.SmallIntegerField.__init__(self,*args, **defaults)
+
+class PercentageField(models.DecimalField):
+    """
+    A field to express a percentage. 
+    The database stores this like a DecimalField.
+    Plain HTML adds a "%".
+    """
+    def __init__(self, *args, **kwargs):
+        defaults = dict(
+            max_length=5,
+            max_digits=5,
+            decimal_places=2,
+            )
+        defaults.update(kwargs)
+        super(PercentageField, self).__init__(*args, **defaults)
+  
+class DatePickerField(models.DateField):
+    """
+    A DateField that uses a DatePicker instead of a normal DateWidget.
+    Doesn't yet work.
+    """
+
+class MonthField(models.DateField):
+    """
+    A DateField that uses a MonthPicker instead of a normal DateWidget
+    """
+    def __init__(self, *args, **kw):
         models.DateField.__init__(self,*args, **kw)
   
 class PriceField(models.DecimalField):
@@ -122,7 +152,33 @@ class PriceField(models.DecimalField):
         #~ return fld
         
         
+"""
+http://stackoverflow.com/questions/454436/unique-fields-that-allow-nulls-in-django
+answer Dec 20 '09 at 3:40 by mightyhal
+http://stackoverflow.com/a/1934764
+"""
+class NullCharField(models.CharField): #subclass the CharField
+    description = "CharField that stores empty strings as NULL instead of ''."
+    def __init__(self, *args, **kwargs):
+        defaults = dict(blank=True,null=True)
+        defaults.update(kwargs)
+        super(NullCharField, self).__init__(*args, **defaults)
         
+    def to_python(self, value):  #this is the value right out of the db, or an instance
+       #~ if isinstance(value, models.CharField): #if an instance, just return the instance
+       if isinstance(value, basestring): #if a string, just return the value
+            return value 
+       if value is None:   #if the db has a NULL (==None in Python)
+            return ''  # convert it into the Django-friendly '' string
+       else:
+            return value # otherwise, return just the value
+            
+    def get_db_prep_value(self, value, connection, prepared=False):
+    #catches value right before sending to db
+       if value == '':     # if Django tries to save '' string, send the db None (NULL)
+            return None
+       else:
+            return value # otherwise, just pass the value        
 
 class FakeField(object):
     """
@@ -204,7 +260,18 @@ class DisplayField(FakeField):
     def save_form_data(self,*args,**kw): raise NotImplementedError
     def value_to_string(self,*args,**kw): raise NotImplementedError
         
+    def value_from_object(self,obj,ar=None):
+        return ''
 
+#~ class DynamicForeignKey(DisplayField):
+    #~ """
+    #~ A pointer to "the" one and only MTI child.
+    #~ This assumes that there is always one and only one child instance among the given models.
+    #~ """
+    #~ def __init__(self,get_child,**kw):
+        #~ self.get_child = get_child
+        #~ VirtualField.__init__(self,models.ForeignKey(**kw),self.has_child)
+        
         
 class HtmlBox(DisplayField):
     """
@@ -217,14 +284,6 @@ class HtmlBox(DisplayField):
     
 #~ from django.db.models.fields import Field
 
-VIRTUAL_FIELDS = []
-
-def resolve_virtual_fields():
-    global VIRTUAL_FIELDS
-    for vf in VIRTUAL_FIELDS: 
-        vf.lino_resolve_type()
-    VIRTUAL_FIELDS = None
-      
 
 class VirtualField(FakeField): # (Field):
     """
@@ -234,7 +293,7 @@ class VirtualField(FakeField): # (Field):
     def __init__(self,return_type,get):
         self.return_type = return_type # a Django Field instance
         self.get = get
-        VIRTUAL_FIELDS.append(self)
+        settings.SITE.register_virtual_field(self)
         """
         Normal VirtualFields are read-only and not editable.
         We don't want to require application developers to explicitly 
@@ -274,6 +333,7 @@ class VirtualField(FakeField): # (Field):
         for k in ('''to_python choices save_form_data 
           value_to_string verbose_name max_length rel
           max_digits decimal_places
+          help_text
           blank'''.split()):
             setattr(self,k,getattr(self.return_type,k,None))
         #~ logger.info('20120831 VirtualField %s on %s',name,actor_or_model)
@@ -428,8 +488,7 @@ class MethodField(VirtualField):
 
 class unused_LinkedForeignKey(generic.GenericForeignKey):
     """
-    Like a GenericForeignKey, but the content type 
-    is not stored in another model.
+    Like a GenericForeignKey, but the content type is not stored in another model.
     Code partly copied from django.contrib.contenttypes GenericForeignKey.
     Used by :mod:`lino.modlib.links`.
     
@@ -619,15 +678,34 @@ class GenericForeignKeyIdField(models.PositiveIntegerField):
     
 class GenericForeignKey(generic.GenericForeignKey):
     """
-    Lino's little extension to Django's GFK.
+    Add verbose_name and help_text to Django's GFK.
     Used by :class:`lino.mixins.Controllable`.
     """
     def __init__(self, ct_field="content_type", fk_field="object_id", 
-          verbose_name=None,help_text=None):
+          verbose_name=None,help_text=None,dont_merge=False):
         self.verbose_name = verbose_name
         self.help_text = help_text
+        self.dont_merge = dont_merge
         generic.GenericForeignKey.__init__(self,ct_field,fk_field)
         
+    #~ def contribute_to_class(self, cls, name):
+        #~ """
+        #~ @chooser(instance_values=True)
+        #~ def object_id_choices(cls,object_type):
+            #~ if object_type:
+                #~ return object_type.model_class().objects.all()
+            #~ return []
+        #~ def get_object_id_display(self,value):
+            #~ if self.object_type:
+                #~ try:
+                    #~ return unicode(self.object_type.get_object_for_this_type(pk=value))
+                #~ except self.object_type.model_class().DoesNotExist,e:
+                    #~ return "%s with pk %r does not exist" % (
+                        #~ full_model_name(self.object_type.model_class()),value)
+        #~ """
+        #~ generic.GenericForeignKey.contribute_to_class(self, cls, name)
+        #~ if not hasattr(cls,
+        
     
 #~ class FieldSet:
     #~ """
@@ -793,7 +871,7 @@ def get_data_elem(model,name):
         #~ mod = import_module(model.__module__)
         #~ rpt = getattr(mod,name,None)
     #~ elif len(s) == 2:
-        #~ mod = getattr(settings.LINO.modules,s[0])
+        #~ mod = getattr(settings.SITE.modules,s[0])
         #~ rpt = getattr(mod,s[1],None)
     #~ else:
         #~ raise Exception("Invalid data element name %r" % name)
@@ -825,6 +903,30 @@ def fields_list(model,field_names):
     #~ if model.__name__ == 'Company':
         #~ print 20110929, [get_field(model,n) for n in field_names.split()]
     #~ return [get_field(model,n).name for n in field_names.split()]
-    return [get_data_elem(model,n).name for n in field_names.split()]
+    lst = []
+    for name in field_names.split():
+        e = get_data_elem(model,name)
+        if e is None:
+            raise models.FieldDoesNotExist("No data element %r in %s" % (name,model))
+        lst.append(e.name)
+    return lst
+    #~ return [get_data_elem(model,n).name for n in field_names.split()]
 
 
+def ForeignKey(othermodel,*args,**kw):
+    """
+    This is almost as 
+    `django.db.models.ForeignKey <https://docs.djangoproject.com/en/dev/ref/models/fields/#foreignkey>`, 
+    except for a subtle difference: 
+    it supports `othermodel` being `None` or the name of some non-installed model
+    and returns a :class:`DummyField <lino.core.fields.DummyField>` 
+    in that case.
+    This difference is useful when designing reusable models.
+    """
+    if othermodel is None: 
+        return DummyField(othermodel,*args,**kw)
+    if isinstance(othermodel,basestring):
+        if not settings.SITE.is_installed_model_spec(othermodel):
+            return DummyField(othermodel,*args,**kw)
+    return models.ForeignKey(othermodel,*args,**kw)
+    
