@@ -28,15 +28,15 @@ from django.core.mail import EmailMessage
 import lino
 from lino.utils import AttrDict
 from lino.utils import curry
-from lino.utils import babel
+from north import babel
 #~ from lino.utils import jsgen
 #~ from lino.utils import Warning
 from lino.utils.xmlgen import html as xghtml
 E = xghtml.E
 
-from lino.ui import requests as ext_requests
+from lino.core import constants as ext_requests
 
-from lino.core.modeltools import resolve_model, resolve_app
+from lino.core.dbutils import resolve_model, resolve_app
 from lino.core import layouts
 #~ from lino.core import changes
 from lino.core import fields
@@ -97,8 +97,7 @@ class EmptyTableRow(VirtualRow):
 class BaseRequest(object):
     def __init__(self,ui,request=None,renderer=None,**kw):
         if ui is None:
-            ui = settings.LINO.ui
-            #~ from lino.ui.extjs3 import ui
+            ui = settings.SITE.ui
         self.ui = ui
         #~ self.error_response = ui.error_response
         #~ self.success_response = ui.success_response
@@ -109,14 +108,17 @@ class BaseRequest(object):
         self.error = ui.error
         self.success = ui.success
         if renderer is None:
-            renderer = ui.text_renderer
+            #~ renderer = ui.text_renderer
+            renderer = ui.ext_renderer
         self.renderer = renderer
         #~ self.step = 0 # confirmation counter
         #~ self.report = actor
         self.request = request
         if request is not None:
-            if request.method == 'PUT':
-                rqdata = http.QueryDict(request.body) # raw_post_data before Django 1.4
+            if request.method in ('PUT','DELETE'):
+                rqdata = http.QueryDict(request.body) 
+                # note that `body` was named `raw_post_data` before Django 1.4
+                #~ print 20130222, rqdata
             else:
                 rqdata = request.REQUEST
             kw = self.parse_req(request,rqdata,**kw)
@@ -130,12 +132,12 @@ class BaseRequest(object):
         kw.update(user=request.user)
         kw.update(subst_user=request.subst_user)
         kw.update(requesting_panel=request.requesting_panel)
-        #~ if settings.LINO.user_model:
+        #~ if settings.SITE.user_model:
             #~ username = rqdata.get(ext_requests.URL_PARAM_SUBST_USER,None)
             #~ if username:
                 #~ try:
-                    #~ kw.update(subst_user=settings.LINO.user_model.objects.get(username=username))
-                #~ except settings.LINO.user_model.DoesNotExist, e:
+                    #~ kw.update(subst_user=settings.SITE.user_model.objects.get(username=username))
+                #~ except settings.SITE.user_model.DoesNotExist, e:
                     #~ pass
         #~ logger.info("20120723 ActionRequest.parse_req() --> %s",kw)
         return kw
@@ -220,7 +222,7 @@ class BaseRequest(object):
         #~ if silent:
             #~ return
         recipients = []
-        for addr in settings.LINO.get_system_note_recipients(self,owner,silent):
+        for addr in settings.SITE.get_system_note_recipients(self,owner,silent):
             if not '@example.com' in addr:
                 recipients.append(addr)
         if not len(recipients):
@@ -400,8 +402,8 @@ class ActionRequest(BaseRequest):
     def render_to_dict(self):
         return self.bound_action.action.render_to_dict(self)
         
-    def get_request_url(self,*args,**kw):
-        return self.ui.get_request_url(self,*args,**kw)
+    #~ def get_request_url(self,*args,**kw):
+        #~ return self.ui.get_request_url(self,*args,**kw)
 
     def get_action_status(self,ba,obj,**kw):
         #~ logger.info("get_action_status %s",ba.full_name())
@@ -457,7 +459,8 @@ class ActionRequest(BaseRequest):
         
     def absolute_uri(self,*args,**kw):
         ar = self.spawn(*args,**kw)
-        location = ar.renderer.get_request_url(ar)
+        #~ location = ar.renderer.get_request_url(ar)
+        location = ar.get_request_url()
         return self.request.build_absolute_uri(location)
         
             
