@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2009-2012 Luc Saffre
+## Copyright 2009-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -46,9 +46,9 @@ u"""
 import logging
 logger = logging.getLogger(__name__)
 
+import os
 import yaml
-
-#~ from lxml import etree
+import json
 
 from django.db import models
 from django.conf import settings
@@ -58,23 +58,27 @@ from django.contrib.contenttypes import generic
 from django.db.models.query import QuerySet
 from django.utils.translation import ugettext_lazy as _
 from django.utils.encoding import force_unicode
-#~ from django.utils import simplejson as json
-import json
+
+from djangosite.utils import rstgen
+
 
 from lino.core import actors
 from lino.core import actions
-from lino.core.modeltools import obj2str
+from lino.core.dbutils import obj2str
 from lino.core.model import Model
 
 from lino.core.fields import FakeField
-from lino.ui import base
-from lino.ui import requests as ext_requests
-from lino.utils.config import Configured, load_config_files
+from lino.core.requests import ActionRequest
 
+from lino.ui import base
+from lino.core import constants #  as ext_requests
+from lino.utils.config import Configured, load_config_files
 
 class InvalidRequest(Exception):
     pass
 
+from lino.utils.xmlgen.html import RstTable
+
 
 class GridConfig(Configured):
   
@@ -142,7 +146,8 @@ class GridConfig(Configured):
 WARNINGS_LOGGED = dict()
 
 
-class TableRequest(actions.ActionRequest):
+
+class TableRequest(ActionRequest):
     """
     An :class:`action request <lino.core.actions.ActionRequest>` 
     on a :class:`Table`.
@@ -169,7 +174,7 @@ class TableRequest(actions.ActionRequest):
     def __init__(self,ui,actor,request=None,action=None,**kw):
         #~ if not (isinstance(actor,type) and issubclass(actor,AbstractTable)):
             #~ raise Exception("Expected an AbstractTable subclass, got %r" % actor)
-        actions.ActionRequest.__init__(self,ui,actor,request,action,**kw)
+        ActionRequest.__init__(self,ui,actor,request,action,**kw)
         #~ self.execute()
         
     def execute(self):
@@ -252,7 +257,7 @@ class TableRequest(actions.ActionRequest):
             """
             #~ if master is ContentType or master is models.Model:
             if master is ContentType or master._meta.abstract:
-                mt = rqdata.get(ext_requests.URL_PARAM_MASTER_TYPE)
+                mt = rqdata.get(constants.URL_PARAM_MASTER_TYPE)
                 try:
                     master = kw['master'] = ContentType.objects.get(pk=mt).model_class()
                 except ContentType.DoesNotExist,e:
@@ -262,7 +267,7 @@ class TableRequest(actions.ActionRequest):
                     
                 #~ print kw
             if not kw.has_key('master_instance'):
-                pk = rqdata.get(ext_requests.URL_PARAM_MASTER_PK,None)
+                pk = rqdata.get(constants.URL_PARAM_MASTER_PK,None)
                 #~ print '20100406a', self.actor,URL_PARAM_MASTER_PK,"=",pk
                 #~ if pk in ('', '-99999'):
                 if pk == '':
@@ -280,7 +285,7 @@ class TableRequest(actions.ActionRequest):
                 #~ print '20100212', self #, kw['master_instance']
         #~ print '20100406b', self.actor,kw
         
-        if settings.LINO.use_filterRow:
+        if settings.SITE.use_filterRow:
             exclude = dict()
             for f in self.ah.store.fields:
                 if f.field:
@@ -302,13 +307,13 @@ class TableRequest(actions.ActionRequest):
             if len(exclude):
                 kw.update(exclude=exclude)
                 
-        if settings.LINO.use_gridfilters:
-            filter = rqdata.get(ext_requests.URL_PARAM_GRIDFILTER,None)
+        if settings.SITE.use_gridfilters:
+            filter = rqdata.get(constants.URL_PARAM_GRIDFILTER,None)
             if filter is not None:
                 filter = json.loads(filter)
-                kw['gridfilters'] = [ext_requests.dict2kw(flt) for flt in filter]
+                kw['gridfilters'] = [constants.dict2kw(flt) for flt in filter]
                 
-        kw = actions.ActionRequest.parse_req(self,request,rqdata,**kw)
+        kw = ActionRequest.parse_req(self,request,rqdata,**kw)
         #~ raise Exception("20120121 %s.parse_req(%s)" % (self,kw))
         
         #~ kw.update(self.report.known_values)
@@ -317,24 +322,24 @@ class TableRequest(actions.ActionRequest):
             #~ if v is not None:
                 #~ kw[fieldname] = v
                 
-        quick_search = rqdata.get(ext_requests.URL_PARAM_FILTER,None)
+        quick_search = rqdata.get(constants.URL_PARAM_FILTER,None)
         if quick_search:
             kw.update(quick_search=quick_search)
             
-        sort = rqdata.get(ext_requests.URL_PARAM_SORT,None)
+        sort = rqdata.get(constants.URL_PARAM_SORT,None)
         if sort:
             #~ self.sort_column = sort
-            sort_dir = rqdata.get(ext_requests.URL_PARAM_SORTDIR,'ASC')
+            sort_dir = rqdata.get(constants.URL_PARAM_SORTDIR,'ASC')
             if sort_dir == 'DESC':
                 sort = '-' + sort
                 #~ self.sort_direction = 'DESC'
             kw.update(order_by=[sort])
         
                 
-        offset = rqdata.get(ext_requests.URL_PARAM_START,None)
+        offset = rqdata.get(constants.URL_PARAM_START,None)
         if offset:
             kw.update(offset=int(offset))
-        limit = rqdata.get(ext_requests.URL_PARAM_LIMIT,None)
+        limit = rqdata.get(constants.URL_PARAM_LIMIT,None)
         if limit:
             kw.update(limit=int(limit))
         
@@ -391,7 +396,7 @@ class TableRequest(actions.ActionRequest):
         
         #~ logger.info("20120121 %s.setup() done",self)
         
-        actions.ActionRequest.setup(self,**kw)
+        ActionRequest.setup(self,**kw)
         
         """
         20120519 : outbox.MyOutbox had no phantom record when called from menu.
@@ -417,17 +422,17 @@ class TableRequest(actions.ActionRequest):
         if ar.request is None:
             columns = None
         else:
-            columns = [str(x) for x in ar.request.REQUEST.getlist(ext_requests.URL_PARAM_COLUMNS)]
+            columns = [str(x) for x in ar.request.REQUEST.getlist(constants.URL_PARAM_COLUMNS)]
         
         if columns:
-            #~ widths = [int(x) for x in ar.request.REQUEST.getlist(ext_requests.URL_PARAM_WIDTHS)]
-            all_widths = ar.request.REQUEST.getlist(ext_requests.URL_PARAM_WIDTHS)
-            hiddens = [(x == 'true') for x in ar.request.REQUEST.getlist(ext_requests.URL_PARAM_HIDDENS)]
+            #~ widths = [int(x) for x in ar.request.REQUEST.getlist(constants.URL_PARAM_WIDTHS)]
+            all_widths = ar.request.REQUEST.getlist(constants.URL_PARAM_WIDTHS)
+            hiddens = [(x == 'true') for x in ar.request.REQUEST.getlist(constants.URL_PARAM_HIDDENS)]
             fields = []
             widths = []
             headers = []
             #~ ah = ar.actor.get_handle(self.extjs_ui)
-            ah = ar.actor.get_handle(settings.LINO.ui)
+            ah = ar.actor.get_handle(settings.SITE.ui)
             for i,cn in enumerate(columns):
                 col = None
                 for e in ah.list_layout.main.columns:
@@ -439,7 +444,8 @@ class TableRequest(actions.ActionRequest):
                     #~ raise Exception("No column named %r in %s" % (cn,ah.list_layout.main.columns))
                     raise Exception("No column named %r in %s" % (cn,ar.ah.list_layout.main.columns))
                 if not hiddens[i]:
-                    fields.append(col.field._lino_atomizer)
+                    fields.append(col)
+                    #~ fields.append(col.field._lino_atomizer)
                     headers.append(unicode(col.label or col.name))
                     widths.append(int(all_widths[i]))
         else:
@@ -447,7 +453,7 @@ class TableRequest(actions.ActionRequest):
                 from lino.core import layouts
                 ll = layouts.ListLayout(column_names,table=ar.actor)
                 #~ lh = ll.get_layout_handle(self.extjs_ui)
-                lh = ll.get_layout_handle(settings.LINO.ui)
+                lh = ll.get_layout_handle(settings.SITE.ui)
                 columns = lh.main.columns
             else:
                 #~ ah = ar.actor.get_handle(self.extjs_ui)
@@ -457,7 +463,8 @@ class TableRequest(actions.ActionRequest):
             #~ fields = ar.ah.store.list_fields
             headers = [unicode(col.label or col.name) for col in columns]
             widths = [(col.width or col.preferred_width) for col in columns]
-            fields = [col.field._lino_atomizer for col in columns]
+            #~ fields = [col.field._lino_atomizer for col in columns]
+            fields = columns
 
         oh = ar.actor.override_column_headers(ar)
         if oh:
@@ -471,7 +478,6 @@ class TableRequest(actions.ActionRequest):
         
         
     def to_rst(self,column_names=None):
-        
         fields, headers, widths = self.get_field_info(column_names)
         
         #~ fields = self.ah.store.list_fields
@@ -486,12 +492,15 @@ class TableRequest(actions.ActionRequest):
                 #~ if header is not None:
                     #~ headers[i] = unicode(header)
                     
+        grid = self.ah.list_layout.main
+                    
         sums  = [fld.zero for fld in fields]
         rows = []  
         recno = 0
         for row in self:
             recno += 1
-            rows.append([x for x in self.ah.store.row2text(self,fields,row,sums)])
+            rows.append([x for x in grid.row2text(self,fields,row,sums)])
+            #~ rows.append([x for x in grid.row2html(self,fields,row,sums)])
                 
         has_sum = False
         for i in sums:
@@ -500,12 +509,12 @@ class TableRequest(actions.ActionRequest):
                 has_sum = True
                 break
         if has_sum:
-            rows.append([x for x in self.ah.store.sums2html(self,fields,sums)])
-        from lino.utils import rstgen
-        return rstgen.table(headers,rows)
-          
-                    
+            rows.append([x for x in grid.sums2html(self,fields,sums)])
+              
+        t = RstTable(headers,**kw)
+        return t.to_rst(rows)
         
+        #~ return HtmlTable(headers,rows)
       
         
         
@@ -517,10 +526,10 @@ class TableRequest(actions.ActionRequest):
         
         
     def get_status(self,ui,**kw):
-        kw = actions.ActionRequest.get_status(self,ui,**kw)
+        kw = ActionRequest.get_status(self,ui,**kw)
         bp = kw['base_params']
         if self.quick_search:
-            bp[ext_requests.URL_PARAM_FILTER] = self.quick_search
+            bp[constants.URL_PARAM_FILTER] = self.quick_search
             
         if self.known_values:
             for k,v in self.known_values.items():
@@ -528,11 +537,11 @@ class TableRequest(actions.ActionRequest):
                     bp[k] = v
         if self.master_instance is not None:
             if self.master is not None:
-                bp[ext_requests.URL_PARAM_MASTER_PK] = self.master_instance.pk
+                bp[constants.URL_PARAM_MASTER_PK] = self.master_instance.pk
                 mt = ContentType.objects.get_for_model(self.master_instance.__class__).pk
-                bp[ext_requests.URL_PARAM_MASTER_TYPE] = mt
+                bp[constants.URL_PARAM_MASTER_TYPE] = mt
             else:
-                bp[ext_requests.URL_PARAM_MASTER_PK] = self.master_instance
+                bp[constants.URL_PARAM_MASTER_PK] = self.master_instance
         return kw
         
         
@@ -650,8 +659,9 @@ class AbstractTable(actors.Actor):
     If this is None, preview requests for this table will request all rows.
     Since preview tables usually have no paging toolbar, that's what we want.
     But if there are many rows, this can lead to waste of performance.
-    Not tested. This was one idea to solve the 20130107 problem 
-    "AvailableCoaches slave table shows only 5 records".
+    
+    Not tested. This was one idea while trying to solve the 20130107 problem 
+    "AvailableCoaches slave table shows only 5 records".    
     """
     
     get_data_rows = None
@@ -669,11 +679,6 @@ class AbstractTable(actors.Actor):
     
     """
     
-    #~ column_defaults = {}
-    #~ """
-    #~ A dictionary of default parameters for :class:`computed columns <ComputedColumn>` on this table.
-    #~ """
-    
     
     auto_fit_column_widths = False
     """
@@ -685,7 +690,7 @@ class AbstractTable(actors.Actor):
     #~ hide_columns = None
     #~ hidden_columns = frozenset()
     
-    hidden_columns = None
+    hidden_columns = frozenset()
     """
     If given, this is specifies the data elements
     that should be hidden by default when rendering 
@@ -702,9 +707,10 @@ class AbstractTable(actors.Actor):
     
     Otherwise it must be specified as a set of strings, 
     each one the name of a data element.
-    
     """
     
+    #~ hidden_elements = None
+    
     form_class = None
     help_url = None
     #master_instance = None
@@ -812,14 +818,28 @@ class AbstractTable(actors.Actor):
         
     @classmethod
     def class_init(self):
+        """
+        Sets table-specific default values for certain attributes.
+        """
         #~ if self.default_action is None:
             #~ self.default_action = actions.GridEdit()
     
         if self.get_data_rows is not None:
             self.show_detail_navigator = False
             
-        if self.editable is None:
+        """
+        :class:`lino_welfare.modellib.debts.models.DistByBudget` 
+        defines its own `get_data_rows` but inherits from 
+        :class:`lino_welfare.modellib.debts.models.EntriesByBudget` 
+        which has no `get_data_rows`.
+        """
+        if self.__dict__.get('editable') is None:
             self.editable = (self.get_data_rows is None)
+            #~ logger.info("20130204 %s editable = %s",self.__name__,self.editable)
+        #~ if self.editable is None:
+            #~ if self.get_data_rows is not None:
+                #~ self.editable = False
+            #~ self.editable = (self.get_data_rows is None)
         super(AbstractTable,self).class_init()
       
       
@@ -979,6 +999,38 @@ class AbstractTable(actors.Actor):
         #~ return VirtualTableRequest(ui,self,request,action,**kw)
         return TableRequest(ui,self,request,action,**kw)
 
+    @classmethod
+    def run_action_from_console(self,pk=None,an=None):
+        """
+        Not yet stable. Used by print_tx25.py.
+        To be combined with the `show` management command.
+        """
+        from north import babel
+        babel.set_language(None)
+        settings.SITE.startup()
+        #~ settings.SITE.ui
+        if pk is not None:
+            elem = self.get_row_by_pk(pk)
+            #~ elem = self.model.objects.get(pk=pk)
+            if an is None:
+                an = self.default_elem_action_name
+        elif an is None:
+            an = self.default_list_action_name
+        ba = self.get_action_by_name(an)
+        #~ print ba
+        ar = self.request(action=ba)
+        #~ ar = TableRequest(None,self,None,ba)
+        kw = ba.action.run(elem,ar)
+        #~ kw = self.check_action_response(kw)
+        msg = kw.get('message')
+        if msg: 
+            print msg
+        url = kw.get('open_url') or kw.get('open_davlink_url')
+        if url:
+            os.startfile(url)
+        
+        
+        
 
 class VirtualTable(AbstractTable):
     """
