@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2009-2012 Luc Saffre
+## Copyright 2009-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -34,6 +34,8 @@ from django.utils.translation import ugettext_lazy as _
 from django.template.loader import render_to_string, get_template, select_template, Context, TemplateDoesNotExist
 from django.http import HttpResponse, HttpResponseRedirect, Http404
 from django.utils.encoding import force_unicode
+from django.utils.translation import string_concat
+
 
 import lino
 #~ from lino import dd
@@ -41,13 +43,12 @@ import lino
 from lino.core import actions
 from lino.core import fields
 from lino.utils import iif, moneyfmt
-from lino.utils import babel 
+from north import babel 
 #~ from lino.utils import call_optional_super
 from lino.utils.choosers import chooser
 from lino.utils.appy_pod import Renderer
 from lino.utils.config import find_template_config_files
-from lino.core.modeltools import makedirs_if_missing
-from lino.core.modeltools import Model
+from lino.core.model import Model
 from lino.mixins.duplicable import Duplicable
 
 
@@ -55,12 +56,12 @@ def decfmt(v,places=2,**kw):
     """
     Format a Decimal value.
     Like :func:`lino.utils.moneyfmt`, but using the site settings
-    :attr:`lino.Lno.decimal_group_separator`
+    :attr:`lino.Lino.decimal_group_separator`
     and
-    :attr:`lino.Lno.decimal_separator`.
+    :attr:`lino.Lino.decimal_separator`.
     """
-    kw.setdefault('sep',settings.LINO.decimal_group_separator)
-    kw.setdefault('dp',settings.LINO.decimal_separator)
+    kw.setdefault('sep',settings.SITE.decimal_group_separator)
+    kw.setdefault('dp',settings.SITE.decimal_separator)
     return moneyfmt(v,places=places,**kw)
 
 
@@ -140,8 +141,8 @@ class BuildMethod:
         #~ self.templates_dir = os.path.join(settings.PROJECT_DIR,'doctemplates',self.templates_name or self.name)
         if self.templates_name is None:
             self.templates_name = self.name
-        #~ self.old_templates_dir = os.path.join(settings.LINO.webdav_root,'doctemplates',self.templates_name)
-        #~ self.templates_url = settings.LINO.webdav_url + '/'.join(('doctemplates',self.templates_name))
+        #~ self.old_templates_dir = os.path.join(settings.SITE.webdav_root,'doctemplates',self.templates_name)
+        #~ self.templates_url = settings.SITE.webdav_url + '/'.join(('doctemplates',self.templates_name))
         
 
             
@@ -156,16 +157,16 @@ class BuildMethod:
         
     def get_target_name(self,action,elem):
         "return the output filename to generate on the server"
-        if self.use_webdav and settings.LINO.use_davlink:
-            return os.path.join(settings.LINO.webdav_root,*self.get_target_parts(action,elem))
+        if self.use_webdav and settings.SITE.use_davlink:
+            return os.path.join(settings.SITE.webdav_root,*self.get_target_parts(action,elem))
         return os.path.join(settings.MEDIA_ROOT,*self.get_target_parts(action,elem))
         
     def get_target_url(self,action,elem,ui):
         "return the url that points to the generated filename on the server"
-        if self.use_webdav and settings.LINO.use_davlink:
-            return settings.LINO.webdav_url + "/".join(self.get_target_parts(action,elem))
+        if self.use_webdav and settings.SITE.use_davlink:
+            return settings.SITE.webdav_url + "/".join(self.get_target_parts(action,elem))
         #~ return settings.MEDIA_URL + "/".join(self.get_target_parts(action,elem))
-        return ui.media_url(*self.get_target_parts(action,elem))
+        return settings.SITE.build_media_url(*self.get_target_parts(action,elem))
             
     def build(self,ar,action,elem):
         raise NotImplementedError
@@ -178,12 +179,12 @@ class DjangoBuildMethod(BuildMethod):
     def get_template(self,action,elem):
         tpls = action.get_print_templates(self,elem)
         if len(tpls) == 0:
-            raise actions.Warning("No templates defined for %r" % elem)
+            raise Warning("No templates defined for %r" % elem)
         #~ logger.debug('make_pisa_html %s',tpls)
         try:
             return select_template(tpls)
         except TemplateDoesNotExist,e:
-            raise actions.Warning("No template found for %s (%s)" % (e,tpls))
+            raise Warning("No template found for %s (%s)" % (e,tpls))
 
     def render_template(self,elem,tpl): # ,MEDIA_URL=settings.MEDIA_URL):
         context = dict(
@@ -269,7 +270,7 @@ class SimpleBuildMethod(BuildMethod):
         tpl_leaf = self.get_template_leaf(action,elem)
         tplfile = find_config_file(tpl_leaf,self.get_group(elem))
         if not tplfile:
-            raise actions.Warning("No file %s / %s" % (self.get_group(elem),tpl_leaf))
+            raise Warning("No file %s / %s" % (self.get_group(elem),tpl_leaf))
         #~ tplfile = os.path.normpath(os.path.join(self.templates_dir,tpl_leaf))
         return self.simple_build(ar,elem,tplfile,target)
         
@@ -305,17 +306,17 @@ class AppyBuildMethod(SimpleBuildMethod):
             ar=ar,
             #~ restify=restify,
             #~ site_config = get_site_config(),
-            site_config=settings.LINO.site_config,
+            site_config=settings.SITE.site_config,
             _ = _,
             #~ knowledge_text=fields.knowledge_text,
             )
         lang = str(elem.get_print_language(self))
         logger.info(u"appy.pod render %s -> %s (language=%r,params=%s",
-            tpl,target,lang,settings.LINO.appy_params)
+            tpl,target,lang,settings.SITE.appy_params)
         #~ savelang = babel.get_language()
         #~ babel.set_language(lang)
         def f():
-            Renderer(tpl, context, target,**settings.LINO.appy_params).run()
+            Renderer(tpl, context, target,**settings.SITE.appy_params).run()
         babel.run_with_language(lang,f)
         #~ babel.set_language(savelang)
         return os.path.getmtime(target)
@@ -498,7 +499,8 @@ class BasePrintAction(actions.RowAction):
             logger.info(u"%s %s -> overwrite existing %s.",bm,elem,filename)
             os.remove(filename)
         else:
-            makedirs_if_missing(os.path.dirname(filename))
+            #~ logger.info("20121221 makedirs_if_missing %s",os.path.dirname(filename))
+            settings.SITE.makedirs_if_missing(os.path.dirname(filename))
         logger.debug(u"%s : %s -> %s", bm,elem,filename)
         return filename
         
@@ -513,6 +515,9 @@ class PrintAction(BasePrintAction):
     
     #~ needs_selection = True
     
+    icon_name = 'x-tbar-print'
+    
+    
     def before_build(self,bm,elem):
         #~ if not elem.must_build:
         if elem.build_time:
@@ -541,7 +546,7 @@ class PrintAction(BasePrintAction):
         else:
             kw.update(message=_("Reused %s printable from cache.") % elem)
         url = bm.get_target_url(self,elem,ar.ui)
-        if bm.use_webdav and settings.LINO.use_davlink:
+        if bm.use_webdav and settings.SITE.use_davlink:
             kw.update(open_davlink_url=ar.request.build_absolute_uri(url))
         else:
             kw.update(open_url=url)
@@ -551,13 +556,14 @@ class PrintAction(BasePrintAction):
     def run(self,elem,ar,**kw):
         #~ kw = self.run_(ar.request,rr.ui,elem,**kw)
         kw = self.run_(ar,elem,**kw)
-        return ar.ui.success_response(**kw)
+        return ar.ui.success(**kw)
       
 class DirectPrintAction(BasePrintAction):
     """
     A Print Action that uses a hard-coded template and no cache.
     """
     url_action_name = None
+    icon_name='x-tbar-print'
     
     #~ def __init__(self,rpt,name,label,bmname,tplname):
     def __init__(self,label=None,tplname='Default',build_method=None,**kw):
@@ -566,7 +572,7 @@ class DirectPrintAction(BasePrintAction):
         #~ if tplname is None: tplname = 'Default'
         super(DirectPrintAction,self).__init__(label,**kw)
         #~ BasePrintAction.__init__(self,rpt,name,label)
-        #~ self.bm =  bm_dict.get(build_method or settings.LINO.preferred_build_method)
+        #~ self.bm =  bm_dict.get(build_method or settings.SITE.preferred_build_method)
         self.build_method = build_method
         self.tplname = tplname
         
@@ -585,7 +591,7 @@ class DirectPrintAction(BasePrintAction):
     def run(self,elem,ar,**kw):
         bm =  bm_dict.get(
             self.build_method or 
-            settings.LINO.site_config.default_build_method)
+            settings.SITE.site_config.default_build_method)
         #~ if self.tplname:
             #~ if not self.tplname.endswith(bm.template_ext):
                 #~ raise Exception("Invalid template for build method %r" % bm.name)
@@ -593,12 +599,12 @@ class DirectPrintAction(BasePrintAction):
         #~ target = settings.MEDIA_URL + "/".join(bm.get_target_parts(self,elem))
         #~ return rr.ui.success_response(open_url=target,**kw)
         url = bm.get_target_url(self,elem,ar.ui)
-        if bm.use_webdav and settings.LINO.use_davlink:
+        if bm.use_webdav and settings.SITE.use_davlink:
             url = ar.request.build_absolute_uri(url)
             kw.update(open_davlink_url=url)
         else:
             kw.update(open_url=url)
-        return ar.ui.success_response(**kw)
+        return ar.ui.success(**kw)
     
 #~ class EditTemplateAction(dd.RowAction):
     #~ name = 'tpledit'
@@ -613,36 +619,41 @@ class ClearCacheAction(actions.RowAction):
     """
     Defines the :guilabel:`Clear cache` button on a Printable record.
     """
-    sort_index = 11
+    sort_index = 51
     url_action_name = 'clear'
     label = _('Clear cache')
+    #~ debug_permissions = 20121127
+    
+    icon_name = 'x-tbar-clearcache'
     
     #~ def disabled_for(self,obj,request):
         #~ if not obj.build_time:
             #~ return True
             
-    def get_action_permission(self,user,obj,state):
+    def get_action_permission(self,ar,obj,state):
         # obj may be None when Lino asks whether this action 
         # should be visible in the UI
         if obj is not None and not obj.build_time:
             return False
-        return super(ClearCacheAction,self).get_action_permission(user,obj,state)
+        return super(ClearCacheAction,self).get_action_permission(ar,obj,state)
     
-    def run(self,elem,rr):
+    def run(self,elem,ar):
+        def doit():
+            #~ elem.must_build = True
+            elem.build_time = None
+            elem.save()
+            return ar.success("%s printable cache has been cleared." % elem,refresh=True)
+            
         t = elem.get_cache_mtime()
         if t is not None and t != elem.build_time:
             #~ logger.info("%r != %r", elem.get_cache_mtime(),elem.build_time)
-            rr.confirm(
+            return ar.confirm(doit,
                 _("This will discard all changes in the generated file."),
                 _("Are you sure?"))
-            logger.info("Got confirmation to discard changes in %s", elem.get_target_name())
+            #~ logger.info("Got confirmation to discard changes in %s", elem.get_target_name())
         #~ else:
             #~ logger.info("%r == %r : no confirmation", elem.get_cache_mtime(),elem.build_time)
-          
-        #~ elem.must_build = True
-        elem.build_time = None
-        elem.save()
-        return rr.ui.success_response("%s printable cache has been cleared." % elem,refresh=True)
+        return doit()
         
         
     
@@ -690,8 +701,8 @@ class PrintableType(Model):
         #~ from lino.models import get_site_config
         if not build_method:
             #~ build_method = get_site_config().default_build_method 
-            #~ build_method = settings.LINO.config.default_build_method 
-            build_method = settings.LINO.site_config.default_build_method 
+            #~ build_method = settings.SITE.config.default_build_method 
+            build_method = settings.SITE.site_config.default_build_method 
         return get_template_choices(cls,build_method)
     
 class Printable(object):
@@ -725,6 +736,13 @@ class CachedPrintable(Duplicable,Printable):
     do_print = PrintAction()
     do_clear_cache = ClearCacheAction()
     
+    #~ @classmethod
+    #~ def get_model_actions(self,table):
+        #~ for x in super(CachedPrintable,self).get_model_actions(table): yield x
+        #~ yield 'do_print',PrintAction()
+        #~ yield 'do_clear_cache',ClearCacheAction()
+    
+    
     
     class Meta:
         abstract = True
@@ -742,8 +760,8 @@ class CachedPrintable(Duplicable,Printable):
             #~ return False
         #~ return super(CachedPrintable,self).get_row_permission(user,state,action)
       
-    def print_from_posting(self,posting,ar):
-        return self.do_print.run(self,ar)
+    def print_from_posting(self,posting,ar,**kw):
+        return self.do_print.run(self,ar,**kw)
         
     def on_duplicate(self,ar,master):
         super(CachedPrintable,self).on_duplicate(ar,master)
@@ -765,8 +783,8 @@ class CachedPrintable(Duplicable,Printable):
         #~ return 'rtf'
         #~ from lino.models import get_site_config
         #~ return get_site_config.default_build_method 
-        return settings.LINO.site_config.default_build_method
-        #~ return settings.LINO.preferred_build_method 
+        return settings.SITE.site_config.default_build_method
+        #~ return settings.SITE.preferred_build_method 
         #~ return 'pisa'
         
     def get_target_name(self):
@@ -800,7 +818,8 @@ class TypedPrintable(CachedPrintable):
     this is :attr:`lino.modlib.sales.models.SalesDocument.imode`.
     """
     
-    type = NotImplementedError
+    #~ type = NotImplementedError
+    type = None
     """
     Override this by a ForeignKey field.
     """
@@ -823,7 +842,7 @@ class TypedPrintable(CachedPrintable):
             return super(TypedPrintable,self).get_build_method()
         if ptype.build_method:
             return ptype.build_method
-        return settings.LINO.site_config.default_build_method 
+        return settings.SITE.site_config.default_build_method 
         
     def get_print_templates(self,bm,action):
         ptype = self.get_printable_type()
@@ -831,8 +850,8 @@ class TypedPrintable(CachedPrintable):
             return super(TypedPrintable,self).get_print_templates(bm,action)
         tplname = ptype.template or bm.default_template
         if not tplname.endswith(bm.template_ext):
-            raise actions.Warning(
-              "Invalid template %r configured for %s %r (expected filename ending with %r)" %
+            raise Warning(
+              "Invalid template %r configured for %s %r (expected filename ending with %r)." %
               (tplname,ptype.__class__.__name__,unicode(ptype),bm.template_ext))
         return [ tplname ]
         #~ return [ ptype.get_templates_group() + '/' + ptype.template ]
