@@ -49,7 +49,6 @@ from lino import dd
 from lino import mixins
 from lino.utils import join_words
 from lino.utils.choosers import chooser
-from lino.utils import babel 
 #~ from lino.models import get_site_config
 
 #~ from lino.modlib.contacts.utils import Genders
@@ -67,7 +66,7 @@ from lino.utils import mti
 from lino.modlib.contacts import MODULE_LABEL
 
 
-class CompanyType(babel.BabelNamed):
+class CompanyType(dd.BabelNamed):
     """
     Represents a possible choice for the  `type`
     field of a :class:`Company`.
@@ -77,7 +76,7 @@ class CompanyType(babel.BabelNamed):
         verbose_name = _("company type")
         verbose_name_plural = _("company types")
         
-    abbr = babel.BabelCharField(_("Abbreviation"),max_length=30,blank=True)
+    abbr = dd.BabelCharField(_("Abbreviation"),max_length=30,blank=True)
     
         
 class CompanyTypes(dd.Table):
@@ -113,7 +112,7 @@ class Partner(mti.MultiTableBase,CountryRegionCity):
     
   
     class Meta:
-        abstract = settings.LINO.is_abstract_model('contacts.Partner')
+        abstract = settings.SITE.is_abstract_model('contacts.Partner')
         verbose_name = _("Partner")
         verbose_name_plural = _("Partners")
   
@@ -142,7 +141,7 @@ class Partner(mti.MultiTableBase,CountryRegionCity):
         #~ max_length=10,blank=True)
     #~ region = models.CharField(_("Region"),
         #~ max_length=200,blank=True)
-    language = babel.LanguageField()
+    language = dd.LanguageField()
     
     email = models.EmailField(_('E-Mail'),blank=True) # ,null=True)
     url = models.URLField(_('URL'),blank=True)
@@ -164,7 +163,7 @@ class Partner(mti.MultiTableBase,CountryRegionCity):
         
     def save(self,*args,**kw):
         if self.id is None:
-            sc = settings.LINO.site_config # get_site_config()
+            sc = settings.SITE.site_config # get_site_config()
             if sc.next_partner_id is not None:
                 self.id = sc.next_partner_id
                 sc.next_partner_id += 1
@@ -222,7 +221,8 @@ but e.g. :class:`PersonMixin` overrides this.
         #~ else:
             #~ foreigner = (self.country != self.objects.get(pk=1).country)
         if self.country is not None:
-            sc = settings.LINO.site_config # get_site_config()
+            sc = settings.SITE.site_config # get_site_config()
+            #~ print 20130228, sc.site_company_id
             if not sc.site_company or self.country != sc.site_company.country: 
                 # (if self.country != sender's country)
                 yield unicode(self.country)
@@ -353,7 +353,7 @@ class Person(PersonMixin,Partner):
     """
     class Meta:
         #~ abstract = True
-        abstract = settings.LINO.is_abstract_model('contacts.Person')
+        abstract = settings.SITE.is_abstract_model('contacts.Person')
         verbose_name = _("Person")
         verbose_name_plural = _("Persons")
 
@@ -427,7 +427,7 @@ class Company(Partner):
     See also :doc:`/tickets/14`.
     """
     class Meta:
-        abstract = settings.LINO.is_abstract_model('contacts.Company')
+        abstract = settings.SITE.is_abstract_model('contacts.Company')
         #~ abstract = True
         app_label = 'contacts'
         verbose_name = _("Company")
@@ -496,8 +496,8 @@ class Companies(Partners):
 
 
 
-# class ContactType(babel.BabelNamed):
-class RoleType(babel.BabelNamed):
+# class ContactType(dd.BabelNamed):
+class RoleType(dd.BabelNamed):
     """
     TODO: rename "RoleType" to "Function" or "ContactType".
     
@@ -779,7 +779,7 @@ class ContactRelated(dd.Model):
         return Person.objects.filter(rolesbyperson__company=company).distinct()
 
     def full_clean(self,*args,**kw):
-        if not settings.LINO.loading_from_dump:
+        if not settings.SITE.loading_from_dump:
             if self.company and self.contact_person is None:
                 qs = self.contact_person_choices_queryset(self.company)
                 #~ qs = self.company.rolesbyparent.all()
@@ -798,13 +798,13 @@ class ContactRelated(dd.Model):
     
 
 
-#~ if settings.LINO.is_installed('contacts'):
+#~ if settings.SITE.is_installed('contacts'):
   
     #~ """
     #~ Don't inject fields if contacts is just being imported from some other module.
     #~ """
     
-#~ dd.inject_field(settings.LINO.user_model,
+#~ dd.inject_field(settings.SITE.user_model,
     #~ 'partner',
     #~ models.ForeignKey(Partner,
         #~ blank=True,null=True,
@@ -812,11 +812,11 @@ class ContactRelated(dd.Model):
 
 
 
-if settings.LINO.is_installed('contacts'):
+if settings.SITE.is_installed('contacts'):
   
-    from lino.models import SiteConfig
+    #~ from lino.models import SiteConfig
 
-    dd.inject_field(SiteConfig,
+    dd.inject_field('ui.SiteConfig',
         'next_partner_id',
         models.IntegerField(default=100, # first 100 for users from demo fixtures.
             verbose_name=_("The next automatic id for Person or Company")
@@ -824,7 +824,7 @@ if settings.LINO.is_installed('contacts'):
         Deserves more documentation.
         """)
         
-    dd.inject_field(SiteConfig,
+    dd.inject_field('ui.SiteConfig',
         'site_company',
         models.ForeignKey("contacts.Company",
             blank=True,null=True,
@@ -836,7 +836,7 @@ if settings.LINO.is_installed('contacts'):
 #~ dd.inject_field(Partner,
     #~ 'is_person',
     #~ mti.EnableChild(
-        #~ settings.LINO.person_model,
+        #~ settings.SITE.person_model,
         #~ verbose_name=_("is Person"),
         #~ help_text=_("Whether this Partner is a Person.")))
 #~ dd.inject_field(Partner,
