@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2011-2012 Luc Saffre
+## Copyright 2011-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -26,17 +26,18 @@ import datetime
 
 
 from django.db import models
+from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import pgettext_lazy
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.contenttypes import generic
 from django.db import IntegrityError
 from django.utils.encoding import force_unicode
+from django.core.exceptions import ValidationError
 
 
 from lino import mixins
 #~ from lino.mixins import mails
-from lino import tools
 from lino import dd
 from lino.core import actions
 
@@ -46,9 +47,8 @@ from lino.core import actions
 #~ from lino.utils import perms
 from lino.utils.restify import restify
 #~ from lino.utils import printable
-from lino.utils import babel
+from north import babel
 #~ from lino.utils import call_optional_super
-from django.conf import settings
 #~ from lino import choices_method, simple_choices_method
 
 #~ from lino.modlib.mails.utils import RecipientType
@@ -56,21 +56,20 @@ from django.conf import settings
 from lino.utils.html2text import html2text
 from django.core.mail import EmailMultiAlternatives
 from lino.utils.config import find_config_file
-from lino.utils.choicelists import ChoiceList
+#~ from lino.utils.choicelists import ChoiceList
 
 
-from Cheetah.Template import Template as CheetahTemplate
+#~ from Cheetah.Template import Template as CheetahTemplate
 #~ from lino.utils import dtosl, dtos
 
-uploads = dd.resolve_app("uploads")
 
 
-class RecipientType(ChoiceList):
+class RecipientType(dd.ChoiceList):
     """
     A list of possible values for the `type` field of a 
     :class:`Recipient`.
     """
-    label = _("Recipient Type")
+    verbose_name = _("Recipient Type")
     
 add = RecipientType.add_item
 add('to',_("to"),'to')
@@ -93,13 +92,25 @@ add('bcc',_("bcc"),'bcc')
     #~ column_names = 'name build_method template *'
     
     
-from lino.utils.config import find_template_config_files
+#~ from lino.utils.config import find_template_config_files
 
 class MailableType(dd.Model):
     """
     Mixin for Models that serve as `type` of a :class:`Mailable`.
+    Concrete examples are cal.Calendar, cal.GuestRole, notes.NoteType
     """
     templates_group = None
+    """
+    Should contain a string "<app_label>/<Model>" of the Mailable 
+    being typed by this MailableType. Example::
+    
+      class NoteType(...,MailableType):
+          templates_group = 'notes/Note'
+          
+      class Note(...,Mailable):
+          type = models.ForeignKey(NoteType)
+
+    """
 
     class Meta:
         abstract = True
@@ -116,9 +127,13 @@ The name of the file to be used as template
 when creating an email from a mailable of this type.
 """)
     
+    #~ @dd.chooser(simple_values=True)
+    #~ def email_template_choices(cls):
+        #~ return find_template_config_files('.eml.html',cls.templates_group)
+      
     @dd.chooser(simple_values=True)
     def email_template_choices(cls):
-        return find_template_config_files('.eml.html',cls.templates_group)
+        return list_templates('.eml.html',cls.templates_group)
       
     
 
@@ -127,9 +142,9 @@ class CreateMail(dd.RowAction):
     """
     Creates an outbox mail and displays it.
     """
-  
-    url_action_name = 'mail'
-    #~ label = _('Create email')
+    url_action_name = 'email'
+    icon_name = 'x-tbar-email_add'
+    help_text = _('Create an email from this')
     #~ label = pgettext_lazy(u'verb',u'Mail')
     label = _('Create email')
     
@@ -137,14 +152,14 @@ class CreateMail(dd.RowAction):
         actions.ShowDetailAction,
         actions.ShowEmptyTable) # but not from InsertRow
     
-    def get_action_permission(self,user,obj,state):
+    def get_action_permission(self,ar,obj,state):
         """
         This action is not available:
         
         - when the user has not email address
         - on an obj whose MailableType is empty or has no :attr:`MailableType.email_template` configured
         """
-        if not user.email:
+        if not ar.get_user().email:
             return False
         if obj is not None:
             mt = obj.get_mailable_type()
@@ -153,7 +168,7 @@ class CreateMail(dd.RowAction):
             #~ if obj.attach_to_email(ar) and obj.get_target_name() is None:
             if mt.attach_to_email and not obj.get_target_name():
                 return False
-        return super(CreateMail,self).get_action_permission(user,obj,state)
+        return super(CreateMail,self).get_action_permission(ar,obj,state)
         
     def run(self,elem,ar,**kw):
       
@@ -178,9 +193,23 @@ class CreateMail(dd.RowAction):
         #~ kw.update(open_url=rr.renderer.get_detail_url(m))
         #~ kw.update(open_url=url)
         kw.update(eval_js=js)
-        return ar.success_response(**kw)
+        return ar.success(**kw)
         
+
+def list_templates(ext,group=''):
+    if group:
+        #~ prefix = os.path.join(*(group.split('/')))
+        def ff(fn):
+            rv = fn.startswith(group) and fn.endswith(ext)
+            #~ logger.info("20130101 %r -> %s", fn,rv)
+            return rv 
+        lst = settings.SITE.jinja_env.list_templates(filter_func=ff)
+        L = len(group) + 1
+        lst = [i[L:] for i in lst]
+        return lst
+    return settings.SITE.jinja_env.list_templates(extensions=[ext])
     
+
 class Mailable(dd.Model):
     """
     Mixin for models that provide a "Post" button.
@@ -190,7 +219,11 @@ class Mailable(dd.Model):
     class Meta:
         abstract = True
         
-    create_mail = CreateMail()
+    @classmethod
+    def get_model_actions(self,table):
+        for x in super(Mailable,self).get_model_actions(table): yield x
+        yield 'create_mail',CreateMail()
+        
     #~ post2 = PostAction(True)
     
     #~ post_as_attachment = models.BooleanField(_("Post as attachment"),default=False)
@@ -207,7 +240,7 @@ class Mailable(dd.Model):
         return self.get_mailable_type().attach_to_email
         #~ return isinstance(self,mixins.CachedPrintable)
         
-    def get_mailable_intro(self,ar):
+    def unused_get_mailable_intro(self,ar):
         mt = self.get_mailable_type()
         #~ tplname = self._meta.app_label + '/' + self.__class__.__name__ + '/email.html'
         fn = find_config_file(mt.email_template,mt.templates_group)
@@ -223,6 +256,37 @@ class Mailable(dd.Model):
         tpl.ar = ar
         return unicode(tpl)
         
+    def get_mailable_intro(self,ar):
+        mt = self.get_mailable_type()
+        #~ print 20130101, mt.email_template
+        name = mt.email_template
+        if mt.templates_group is not None:
+            #~ prefix = os.path.join(*(mt.templates_group.split('/')))
+            #~ name = os.path.join(prefix,name)
+            name = mt.templates_group + "/" + name
+        tpl = settings.SITE.jinja_env.get_template(name)
+        context = dict(
+          instance = self,
+          dtosl = babel.dtosl,
+          dtos = babel.dtos,
+          ar = ar,
+        )
+        return tpl.render(**context)
+        
+        #~ # tplname = self._meta.app_label + '/' + self.__class__.__name__ + '/email.html'
+        #~ fn = find_config_file(mt.email_template,mt.templates_group)
+        #~ if fn is None:
+            #~ raise Exception("No config file %s / %s" % (mt.templates_group,mt.email_template))
+            #~ # return ''
+        #~ # logger.info("Using email template %s",fn)
+        #~ tpl = CheetahTemplate(file(fn).read().decode('utf-8'))
+        #~ # tpl.self = elem # doesn't work because Cheetah adds itself a name 'self' 
+        #~ tpl.instance = self
+        #~ tpl.dtosl = babel.dtosl
+        #~ tpl.dtos = babel.dtos
+        #~ tpl.ar = ar
+        #~ return unicode(tpl)
+        
     #~ def get_mailable_body(self,ar):
         #~ raise NoteImplementdError()
         
@@ -239,7 +303,7 @@ class Recipient(dd.Model):
     """
     Abstract base for :class:`inbox.Recipient` and :class:`outbox.Recipient`.
     """
-    allow_cascaded_delete = True
+    allow_cascaded_delete = ['mail']
     
     class Meta:
         verbose_name = _("Recipient")
@@ -271,25 +335,24 @@ class Recipient(dd.Model):
                 self.name = self.partner.get_full_name(salutation=False)
         super(Recipient,self).full_clean()
         
-    def get_row_permission(self,user,state,action):
+    def get_row_permission(self,ar,state,ba):
         """
         Recipients of a Mail may not be edited if the Mail is read-only.
         """
-        if self.mail_id and not self.mail.get_row_permission(user,state,action):
+        if self.mail_id and not self.mail.get_row_permission(ar,state,ba):
+            #~ logger.info("20120920 Recipient.get_row_permission()")
             return False
-        return super(Recipient,self).get_row_permission(user,state,action)
+        return super(Recipient,self).get_row_permission(ar,state,ba)
       
-
-
 class Recipients(dd.Table):
-    required = dict(user_level='manager',user_groups='office')
+    required = dd.required(user_level='manager',user_groups='office')
     #~ required_user_level = UserLevels.manager
     model = Recipient
     #~ column_names = 'mail  type *'
     #~ order_by = ["address"]
-
+    
 class RecipientsByMail(Recipients):
-    required = dict()
+    required = dd.required()
     #~ required_user_level = None
     master_key = 'mail'
     column_names = 'partner:20 address:20 name:20 type:10 *'
@@ -303,6 +366,7 @@ class SendMail(dd.RowAction):
     Sends this as an email.
     """
   
+    icon_name = 'x-tbar-email_send'
     url_action_name = 'send'
     label = _('Send email')
     callable_from = (actions.GridEdit, 
@@ -311,14 +375,14 @@ class SendMail(dd.RowAction):
     
     #~ callable_from = None
             
-    def get_action_permission(self,user,obj,state):
+    def get_action_permission(self,ar,obj,state):
         if obj is not None and obj.sent:
             return False
-        return super(SendMail,self).get_action_permission(user,obj,state)
+        return super(SendMail,self).get_action_permission(ar,obj,state)
         
     def run(self,elem,ar,**kw):
         #~ if elem.sent:
-            #~ return rr.ui.error_response(message='Mail has already been sent.')
+            #~ return rr.ui.error(message='Mail has already been sent.')
         #~ subject = elem.subject
         #~ sender = "%s <%s>" % (rr.get_user().get_full_name(),rr.get_user().email)
         sender = "%s <%s>" % (elem.user.get_full_name(),elem.user.email)
@@ -348,11 +412,11 @@ class SendMail(dd.RowAction):
             #~ else:
                 #~ logger.info("Ignoring recipient %s (type %s)",r,r.type)
         if not found:
-            return ar.error_response("No recipients found.")
+            return ar.error("No recipients found.")
         if len(missing_addresses):
             msg = _("There are recipients without address: ")
             msg += ', '.join([unicode(r) for r in missing_addresses])
-            return ar.error_response(msg,alert=True)
+            return ar.error(msg,alert=True)
         #~ as_attachment = elem.owner.attach_to_email(rr)
         #~ body = elem.body
         #~ if as_attachment:
@@ -372,6 +436,7 @@ class SendMail(dd.RowAction):
                 raise Warning(_("Couldn't find target file of %s") % att.owner)
             msg.attach_file(fn)
             
+        uploads = dd.resolve_app("uploads")
         for up in uploads.UploadsByController.request(ar.ui,master_instance=elem):
         #~ for up in uploads.Upload.objects.filter(owner=elem):
             fn = os.path.join(settings.MEDIA_ROOT,up.file.name)
@@ -393,7 +458,7 @@ class SendMail(dd.RowAction):
         if elem.owner:
             elem.owner.after_send_mail(elem,ar,kw)
         elem.save()
-        return ar.success_response(**kw)
+        return ar.success(**kw)
 
 
 
@@ -407,7 +472,7 @@ class Mail(mixins.AutoUser,mixins.Printable,mixins.ProjectRelated,mixins.Control
     send_mail = SendMail()
     
     date = models.DateField(verbose_name=_("Date"),
-        auto_now_add=True,
+        #~ auto_now_add=True,
         help_text="""
         The official date to be printed on the document.
         """)
@@ -421,17 +486,27 @@ class Mail(mixins.AutoUser,mixins.Printable,mixins.ProjectRelated,mixins.Control
     #~ type = models.ForeignKey(MailType,null=True,blank=True)
     
         
-    #~ sender = models.ForeignKey(settings.LINO.user_model,
+    #~ sender = models.ForeignKey(settings.SITE.user_model,
         #~ verbose_name=_("Sender"))
         #~ related_name='outmails_by_sender',
         #~ blank=True,null=True)
     sent = models.DateTimeField(null=True,editable=False)
 
+    def on_create(self,ar):
+        self.date = datetime.date.today()
+        super(Mail,self).on_create(ar)
+        
+        
     #~ def disabled_fields(self,ar):
         #~ if not self.owner.post_as_attachment:
             #~ return ['body']
         #~ return []
         
+    #~ @classmethod
+    #~ def get_model_actions(self,table):
+        #~ for x in super(Mail,self).get_model_actions(table): yield x
+        #~ yield 'send_mail',SendMail()
+        
     def get_print_language(self,bm):
         if self.user is not None:
             return self.user.language
@@ -448,15 +523,15 @@ class Mail(mixins.AutoUser,mixins.Printable,mixins.ProjectRelated,mixins.Control
         return ', '.join(recs)
     recipients = dd.VirtualField(dd.HtmlBox(_("Recipients")),get_recipients)
         
-    def get_row_permission(self,user,state,action):
+    def get_row_permission(self,ar,state,ba):
         """
         Mails may not be edited after they have been sent.
         """
-        if self.sent and not action.readonly:
+        if self.sent and not ba.action.readonly:
+            #~ logger.info("20120920 Mail.get_row_permission()")
             return False
-        return super(Mail,self).get_row_permission(user,state,action)
+        return super(Mail,self).get_row_permission(ar,state,ba)
       
-dd.update_field(Mail,'user',verbose_name=_("Sender"))
 
 #~ class MailDetail(dd.FormLayout):
     #~ main = """
@@ -464,23 +539,29 @@ dd.update_field(Mail,'user',verbose_name=_("Sender"))
 
 class Mails(dd.Table):
     #~ read_access = dd.required(user_level='manager')
-    required = dict(user_level='manager',user_groups='office')
+    required = dd.required(user_level='manager',user_groups='office')
     model = Mail
     column_names = "sent recipients subject * body"
     order_by = ["sent"]
-    detail_template = """
+    detail_layout = dd.FormLayout("""
     subject project date 
     user sent #build_time id owner
     RecipientsByMail:50x5 AttachmentsByMail:20x5 uploads.UploadsByController:20x5
     body:90x10
-    """
+    """)
+    insert_layout = dd.FormLayout("""
+    project 
+    subject 
+    body
+    """,window_size=(60,20))
     
-if not settings.LINO.project_model:
-    Mails.detail_template.replace('project','')
+if not settings.SITE.project_model:
+    Mails.detail_layout.remove_element('project')
     
     
 class MyOutbox(Mails):
-    required = dict()
+    required = dd.required(user_groups='office')
+    
     #~ required_user_level = None
     #~ known_values = dict(outgoing=True)
     label = _("My Outbox")
@@ -498,14 +579,14 @@ class MyOutbox(Mails):
     #~ filter = models.Q(sent__isnull=False)
     
 class MailsByController(Mails):
-    required = dict()
+    required = dd.required()
     master_key = 'owner'
     #~ label = _("Postings")
     #~ slave_grid_format = 'summary'
 
   
 class MailsByUser(Mails):
-    required = dict()
+    required = dd.required()
     label = _("Outbox")
     column_names = 'sent subject recipients'
     #~ order_by = ['sent']
@@ -513,7 +594,7 @@ class MailsByUser(Mails):
     master_key = 'user'
 
 class MailsByProject(Mails):
-    required = dict()
+    required = dd.required()
     label = _("Outbox")
     column_names = 'date subject recipients user *'
     #~ order_by = ['sent']
@@ -521,7 +602,7 @@ class MailsByProject(Mails):
     master_key = 'project'
     
 class SentByPartner(Mails):
-    required = dict()
+    required = dd.required()
     master = 'contacts.Partner'
     label = _("Outbox")
     column_names = 'sent subject user'
@@ -539,7 +620,7 @@ class SentByPartner(Mails):
 
 class Attachment(mixins.Controllable):
   
-    allow_cascaded_delete = True
+    allow_cascaded_delete = ['mail']
     
     class Meta:
         verbose_name = _("Attachment")
@@ -552,9 +633,10 @@ class Attachment(mixins.Controllable):
             return unicode(self.owner)
         return unicode(self.id)
         
-    def save(self,*args,**kw):
+    def unused_save(self,*args,**kw):
+        # see blog/2012/0929
         if not hasattr(self.owner,'get_target_url'):
-            raise Exception("Controllers of Attachment must define a method `get_target_url`.")
+            raise ValidationError("Controller %r has no method `get_target_url`." % self.owner)
         super(Attachment,self).save(*args,**kw)
         
     def summary_row(self,ar,**kw):
@@ -568,9 +650,9 @@ class Attachment(mixins.Controllable):
         
 class Attachments(dd.Table):
     model = Attachment
-    required = dict(user_groups='office')
+    required = dd.required(user_groups='office')
     #~ window_size = (400,500)
-    #~ detail_template = """
+    #~ detail_layout = """
     #~ mail owner
     #~ """
     
@@ -585,25 +667,37 @@ class AttachmentsByController(Attachments):
 
 
 MODULE_LABEL = _("Outbox")
-  
-def setup_main_menu(site,ui,user,m): pass
 
-def setup_my_menu(site,ui,user,m): 
+lino = dd.resolve_app('ui')
+
+def setup_main_menu(site,ui,profile,m):
+    m  = m.add_menu("office",lino.OFFICE_MODULE_LABEL)
+    m.add_action(MyOutbox)
+
+  
+#~ def setup_main_menu(site,ui,user,m): pass
+
+def unused_setup_my_menu(site,ui,profile,m): 
     m  = m.add_menu("outbox",MODULE_LABEL)
     #~ m.add_action(MyInbox)
     m.add_action(MyOutbox)
     #~ m.add_action(MySent)
   
-def setup_config_menu(site,ui,user,m):
+#~ def setup_config_menu(site,ui,user,m):
     #~ if user.level >= UserLevels.manager:
-    m  = m.add_menu("outbox",MODULE_LABEL)
+    #~ m  = m.add_menu("outbox",MODULE_LABEL)
     #~ m.add_action(MailTypes)
   
-def setup_explorer_menu(site,ui,user,m):
+def setup_explorer_menu(site,ui,profile,m):
     #~ if user.level >= UserLevels.manager:
-    m  = m.add_menu("outbox",MODULE_LABEL)
+    m  = m.add_menu("office",lino.OFFICE_MODULE_LABEL)
+    #~ m  = m.add_menu("outbox",MODULE_LABEL)
     m.add_action(Mails)
+    m.add_action(Attachments)
   
   
-dd.add_user_group('office',MODULE_LABEL)
-  
\ No newline at end of file
+#~ dd.add_user_group('office',MODULE_LABEL)
+  
+dd.update_field(Mail,'user',verbose_name=_("Sender"))
+
+
