@@ -16,6 +16,8 @@
 
 """
 
+from __future__ import unicode_literals
+
 import logging
 logger = logging.getLogger(__name__)
 import datetime
@@ -39,8 +41,6 @@ from lino import dd
 from lino.core import actions
 from lino import mixins
 from lino.utils import mti
-from lino.utils import babel 
-#~ from lino.utils.babel import add_babel_field, babelattr
 #~ from lino.utils.quantities import Duration
 
 
@@ -48,7 +48,7 @@ from lino.utils import babel
 #~ journals = models.get_app('journals')
 #~ auth = resolve_app('auth')
 #~ from lino.modlib.users import models as auth
-contacts = dd.resolve_app('contacts')
+partners = dd.resolve_app(settings.SITE.partners_app_label)
 accounts = dd.resolve_app('accounts')
 ledger = dd.resolve_app('ledger')
 vat = dd.resolve_app('vat')
@@ -83,7 +83,7 @@ add('40',_("Sent"),'sent',editable=False)
 add('50',_("Paid"),'paid',editable=False)
 
 
-class PaymentTerm(babel.BabelNamed):
+class PaymentTerm(dd.BabelNamed):
     """
     A convention on how an Invoice should be paid. 
     """
@@ -112,7 +112,7 @@ class PaymentTerms(dd.Table):
     order_by = ["id"]
   
 
-class InvoicingMode(mixins.PrintableType,babel.BabelNamed):
+class InvoicingMode(mixins.PrintableType,dd.BabelNamed):
     """Represents a method of issuing/sending invoices.
     """
     class Meta:
@@ -135,7 +135,7 @@ How many days in advance invoices should be posted so that the customer
 has a chance to pay them in time.""")
     
     #~ def __unicode__(self):
-        #~ return unicode(babel.babelattr(self,'name'))
+        #~ return unicode(dd.babelattr(self,'name'))
         
 #~ add_babel_field(InvoicingMode,'name')
         
@@ -145,7 +145,7 @@ class InvoicingModes(dd.Table):
     
     
     
-class ShippingMode(babel.BabelNamed):
+class ShippingMode(dd.BabelNamed):
     price = dd.PriceField(blank=True,null=True)
     class Meta:
         verbose_name = _("Shipping Mode")
@@ -179,7 +179,7 @@ class SalesRule(dd.Model):
     payment_term = models.ForeignKey(PaymentTerm,blank=True,null=True)
     
     #~ def __unicode__(self):
-        #~ return u"SalesRule %d" % (self.id)
+        #~ return "SalesRule %d" % (self.id)
         
 #~ def get_sales_rule(doc):
     #~ for r in SalesRule.objects.all().order_by("id"):
@@ -261,7 +261,7 @@ class SalesDocument(
     #~ or inherit it from Voucher (as does Invoice)
     """
     
-    compute_totals = True
+    auto_compute_totals = True
     
     class Meta:
         abstract = True
@@ -273,28 +273,31 @@ class SalesDocument(
         #~ related_name="%(app_label)s_%(class)s_by_contact",
         #~ related_name="%(app_label)s_%(class)s_related",
         #~ )
-    language = babel.LanguageField(default=babel.DEFAULT_LANGUAGE)
+    language = dd.LanguageField()
     
     #~ customer = models.ForeignKey(Customer,
         #~ related_name="customer_%(class)s")
     #~ ship_to = models.ForeignKey(Customer,
         #~ blank=True,null=True,
         #~ related_name="shipTo_%(class)s")
-    your_ref = models.CharField(max_length=200,blank=True)
-    imode = models.ForeignKey(InvoicingMode,blank=True)
+    your_ref = models.CharField(_("Your reference"),max_length=200,blank=True)
+    imode = models.ForeignKey(InvoicingMode,blank=True,null=True)
     shipping_mode = models.ForeignKey(ShippingMode,blank=True,null=True)
     payment_term = models.ForeignKey(PaymentTerm,blank=True,null=True)
-    sales_remark = models.CharField("Remark for sales",
-      max_length=200,blank=True)
-    subject = models.CharField("Subject line",max_length=200,blank=True)
+    #~ sales_remark = models.CharField("Remark for sales",
+      #~ max_length=200,blank=True)
+    subject = models.CharField(_("Subject line"),max_length=200,blank=True)
     #~ vat_exempt = models.BooleanField(default=False)
     #~ item_vat = models.BooleanField(default=False)
     #~ total_base = dd.PriceField(blank=True,null=True)
     #~ total_vat = dd.PriceField(blank=True,null=True)
     intro = models.TextField("Introductive Text",blank=True)
-    #~ user = models.ForeignKey(settings.LINO.user_model,blank=True,null=True)
+    #~ user = models.ForeignKey(settings.SITE.user_model,blank=True,null=True)
     #status = models.CharField(max_length=1, choices=STATUS_CHOICES)
-    discount = models.IntegerField(_("Discount"),blank=True,null=True)
+    #~ discount = models.IntegerField(_("Discount"),blank=True,null=True)
+    discount = dd.PercentageField(_("Discount"),blank=True,null=True)
+    
+    
         
     #~ @dd.chooser()
     #~ def partner_choices(self):
@@ -324,8 +327,8 @@ class SalesDocument(
             #~ return None
         #~ return self.total_base + self.total_vat
     
-    def update_totals(self):
-        #~ logger.info("20121202 sales.update_totals()")
+    def unused_compute_totals(self):
+        #~ logger.info("20121202 sales.compute_totals()")
         if self.pk is None:
             return
         total_base = 0
@@ -345,8 +348,12 @@ class SalesDocument(
 
             
     def full_clean(self,*args,**kw):
-        if self.imode_id is None:
-            self.imode_id = 1 # self.partner
+        """
+        """
+        if self.imode is None:
+            #~ self.imode_id = 1 # self.partner
+            #~ self.imode_id = self.partner.imode
+            self.imode = self.partner.imode
         super(SalesDocument,self).full_clean(*args,**kw)
         #~ r = get_sales_rule(self)
         #~ if r is None:
@@ -357,7 +364,6 @@ class SalesDocument(
             #~ self.shipping_mode = r.shipping_mode
         #~ if self.shipping_mode is None:
             #~ self.shipping_mode = r.shipping_mode
-        self.update_totals()
       
 #~ SALES_PRINTABLE_FIELDS = dd.fields_list(SalesDocument,
   #~ 'customer imode payment_term '
@@ -377,7 +383,7 @@ class SalesDocuments(dd.Table):
         
 
 
-class Invoice(SalesDocument,ledger.Voucher):
+class Invoice(SalesDocument,ledger.Voucher,mixins.Registrable):
     """
     An invoice usually used for selling something.
     """
@@ -392,6 +398,8 @@ class Invoice(SalesDocument,ledger.Voucher):
     
     workflow_state_field = 'state'
     
+    #~ _registrable_fields = set('date author partner vat_regime payment_term due_date'.split())
+    
     def full_clean(self,*args,**kw):
         if self.due_date is None:
             if self.payment_term is not None:
@@ -400,50 +408,62 @@ class Invoice(SalesDocument,ledger.Voucher):
         #SalesDocument.before_save(self)
         #ledger.LedgerDocumentMixin.before_save(self)
         super(Invoice,self).full_clean(*args,**kw)
-
-    #~ def items(self,ar):
-        #~ return ar.spawn(ItemsByInvoice,master_instance=self)
         
+        
+    @classmethod
+    def get_registrable_fields(cls,site):
+        for f in super(Invoice,cls).get_registrable_fields(site): yield f
+        yield 'due_date'
+        yield 'order'
+        
+        yield 'payment_term'
+        yield 'imode'
+        yield 'shipping_mode'
+        yield 'discount'
+        
+        yield 'date'
+        yield 'user'
+        yield 'partner'
+        yield 'vat_regime'
+        yield 'item_vat'
 
-    #~ def get_wanted_movements(self):
-        #~ yield self.create_movement(
-          #~ settings.LINO.get_base_account(self),
-          #~ self.total_base)
-        #~ if self.total_vat:
-            #~ yield self.create_movement(
-              #~ settings.LINO.get_vat_account(self),
-              #~ self.total_vat)
-        #~ yield self.create_movement(
-          #~ settings.LINO.site_config.customers_account,
-          #~ self.total_base+self.total_vat)
 
 
 class ProductDocItem(ledger.VoucherItem,vat.QtyVatItemBase):
     product = models.ForeignKey('products.Product',blank=True,null=True)
     #~ title = models.CharField(max_length=200,blank=True)
     description = dd.RichTextField(_("Description"),blank=True,null=True)
-    discount = models.IntegerField(_("Discount"),default=0)
+    #~ discount = models.IntegerField(_("Discount"),default=0)
+    discount = dd.PercentageField(_("Discount"),blank=True,null=True)
+
     
     def get_base_account(self,tt):
-        ref = settings.LINO.get_product_base_account(tt,self.product)
+        ref = settings.SITE.get_product_base_account(tt,self.product)
         return self.voucher.journal.chart.get_account_by_ref(ref)
         
     def get_vat_class(self,tt):
-        name = settings.LINO.get_product_vat_class(tt,self.product)
+        name = settings.SITE.get_product_vat_class(tt,self.product)
         return vat.VatClasses.get_by_name(name)
         
     #~ def full_clean(self,*args,**kw):
         #~ super(ProductDocItem,self).full_clean(*args,**kw)
 
+    def discount_changed(self,ar):
+        if self.product:
+            if self.product.price is not None:
+                if self.discount is None:
+                    self.unit_price = self.product.price 
+                else:
+                    self.unit_price = self.product.price * (HUNDRED - self.discount) / HUNDRED                    
+                self.unit_price_changed(ar)
+                
     def product_changed(self,ar):
         if self.product:
             self.title = self.product.name
             self.description = self.product.description
             if self.qty is None:
                 self.qty = Decimal("1")
-            if self.product.price is not None:
-                self.unit_price = self.product.price * (HUNDRED - self.discount) / HUNDRED
-                self.unit_price_changed(ar)
+            self.discount_changed(ar)
         
     def before_ui_save(self,ar):
         #~ if self.product:
@@ -464,10 +484,10 @@ class InvoiceItem(ProductDocItem):
 
 
 class InvoiceDetail(dd.FormLayout):
-    main = "general ledger"
+    main = "general more ledger"
     
     totals = dd.Panel("""
-    discount
+    # discount
     total_base
     total_vat
     total_incl
@@ -475,17 +495,22 @@ class InvoiceDetail(dd.FormLayout):
     """,label=_("Totals"))
     
     invoice_header = dd.Panel("""
-    id date partner language
-    order your_ref subject 
-    imode due_date:20 shipping_mode payment_term  vat_regime item_vat
-    user sales_remark project 
-    """,label=_("Header"))
+    date partner vat_regime 
+    order subject your_ref 
+    payment_term due_date:20 
+    imode shipping_mode     
+    """,label=_("Header")) # sales_remark 
     
     general = dd.Panel("""
     invoice_header:60 totals:20
     ItemsByInvoice
     """,label=_("General"))
     
+    more = dd.Panel("""
+    id user language project item_vat
+    intro
+    """,label=_("More"))
+    
     ledger = dd.Panel("""
     journal year number narration
     ledger.MovementsByVoucher
@@ -524,7 +549,7 @@ class InvoicesByJournal(Invoices):
     #master = journals.Journal
     column_names = "number date due_date " \
                   "partner " \
-                  "total_incl order subject:10 sales_remark:10 " \
+                  "total_incl order subject:10 " \
                   "total_base total_vat user *"
                   #~ "ledger_remark:10 " \
                   
@@ -536,7 +561,7 @@ class InvoicesByJournal(Invoices):
         return unicode(ar.master_instance)
                   
 
-if settings.LINO.project_model:
+if settings.SITE.project_model:
   
     class InvoicesByProject(Invoices):
         order_by = ['-date']
@@ -593,7 +618,11 @@ class ItemsByDocument(dd.Table):
     
 
 class ItemsByInvoice(ItemsByDocument):
+    #~ debug_permissions = 20130128
     model = InvoiceItem
+    auto_fit_column_widths = True
+    column_names = "seqno:3 product title description:20x1 discount unit_price qty total_incl total_base total_vat"
+    hidden_columns = "seqno description total_base total_vat"
     
 
 class InvoiceItemsByProduct(ItemsByInvoice):
@@ -659,35 +688,34 @@ ledger.VoucherTypes.add_item(Invoice,InvoicesByJournal)
         
 
 
-def customize_contacts():
+def customize_partners():
 
     #~ for ms in 'contacts.Partner', 'contacts.Person', 'contacts.Company':
-    dd.inject_field('contacts.Partner',
+    partner_model = settings.SITE.partners_app_label + '.Partner'
+    dd.inject_field(partner_model,
         'payment_term',
         models.ForeignKey(PaymentTerm,
             blank=True,null=True,
             help_text=_("The default payment term for sales invoices to this customer.")))
         
-    dd.inject_field('contacts.Partner',
+    dd.inject_field(partner_model,
         'vat_regime',
         vat.VatRegimes.field(
             blank=True,
             help_text=_("The default VAT regime for sales to this customer.")))
             
-    dd.inject_field('contacts.Partner',
+    dd.inject_field(partner_model,
         'item_vat',
         models.BooleanField(
             default=False,
             help_text=_("The default item VAT setting for sales to this customer.")))
         
+    dd.inject_field(partner_model,
+        'imode',
+        models.ForeignKey(InvoicingMode,blank=True,null=True))
+        
+        
 
-#~ def customize_contacts():
-
-    #~ dd.inject_field('contacts.Partner',
-        #~ 'is_customer',
-        #~ mti.EnableChild('sales.Customer',verbose_name=_("is Customer")),
-        #~ """Whether this Partner is also a Customer."""
-        #~ )
 
 
 MODULE_LABEL = _("Sales")
@@ -699,16 +727,15 @@ def site_setup(site):
             sales.InvoiceItemsByProduct
             """,
             label=MODULE_LABEL)
-    #~ if site.is_installed('contacts'):
-    for t in (site.modules.contacts.Partners,
-              site.modules.contacts.Persons,
-              site.modules.contacts.Companies):
-        t.add_detail_tab("sales",
-            """
-            payment_term vat_regime item_vat
-            sales.InvoicesByPartner
-            """,
-            label=MODULE_LABEL)
+    #~ for t in (site.modules.partners.Partners,
+              #~ site.modules.partners.Persons,
+              #~ site.modules.partners.Organisations):
+    site.modules[settings.SITE.partners_app_label].Partners.add_detail_tab("sales",
+        """
+        payment_term vat_regime item_vat imode
+        sales.InvoicesByPartner
+        """,
+        label=MODULE_LABEL)
     #~ if site.is_installed('tickets'):
         #~ site.modules.tickets.Projects.add_detail_tab("sales","sales.InvoicesByProject")
     #~ site.modules.lino.SiteConfigs.add_detail_tab("sales","""
@@ -742,7 +769,7 @@ def setup_config_menu(site,ui,profile,m):
 def setup_explorer_menu(site,ui,profile,m):
     pass
   
-customize_contacts()
+customize_partners()
 #~ customize_siteconfig()
 
   
\ No newline at end of file
