@@ -1,4 +1,4 @@
-## Copyright 2011-2012 Luc Saffre
+## Copyright 2011-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -27,9 +27,10 @@ from django.contrib.auth.hashers import (
 
 
 from lino import dd
-from lino.utils import babel
+from north import babel
 from lino.utils import mti
-from lino.utils import choicelists
+from lino.utils.xmlgen.html import E
+#~ from lino.utils import choicelists
 from lino.utils.choosers import chooser
 from lino import mixins
 from lino.core import actions
@@ -42,11 +43,11 @@ from lino.core import actions
 
 #~ from lino.core.perms import UserLevels
 
-#~ if settings.LINO.is_installed('users') and settings.LINO.user_model != 'users.User':
+#~ if settings.SITE.is_installed('users') and settings.SITE.user_model != 'users.User':
     #~ raise Exception("""\
 #~ You are using lino.modlib.users in your INSTALLED_APPS, 
-#~ but settings.LINO.user_model is %r (should be 'users.User').
-#~ """ % settings.LINO.user_model)
+#~ but settings.SITE.user_model is %r (should be 'users.User').
+#~ """ % settings.SITE.user_model)
 
 class User(mixins.CreatedModified):
     """
@@ -64,9 +65,11 @@ class User(mixins.CreatedModified):
     fields like first_name, last_name, email, access rights for the new user.    
     """
     
-    _lino_preferred_width = 15 
+    preferred_foreignkey_width = 15 
     
-    authenticated = True
+    hidden_columns = 'password remarks'
+    
+    #~ authenticated = True
     
     class Meta:
         verbose_name = _('User')
@@ -89,9 +92,9 @@ class User(mixins.CreatedModified):
     
     remarks = models.TextField(_("Remarks"),blank=True) # ,null=True)
     
-    language = babel.LanguageField(default=models.NOT_PROVIDED)
+    language = dd.LanguageField(default=models.NOT_PROVIDED)
     
-    if settings.LINO.is_installed('contacts'):
+    if settings.SITE.is_installed('contacts'):
       
         partner = models.ForeignKey('contacts.Partner',blank=True,null=True)
         
@@ -110,13 +113,13 @@ class User(mixins.CreatedModified):
             return self.username
         return u'%s %s' % (self.first_name.strip(), self.last_name.strip())
         
-    @dd.displayfield(_("Name"))
+    @dd.displayfield(_("Name"),max_length=15)
     def name_column(self,request):
         #~ return join_words(self.last_name.upper(),self.first_name)
         return unicode(self)
 
 
-    if settings.LINO.is_installed('contacts'):
+    if settings.SITE.is_installed('contacts'):
         def get_person(self):
             if self.partner:
                 return self.partner.get_mti_child('person')
@@ -152,7 +155,7 @@ class User(mixins.CreatedModified):
         else:
             l = []
         #~ if self.profile:
-            #~ l += settings.LINO.user_profile_fields
+            #~ l += settings.SITE.user_profile_fields
         return l
         
     def full_clean(self,*args,**kw):
@@ -198,6 +201,28 @@ class User(mixins.CreatedModified):
     def has_usable_password(self):
         return is_password_usable(self.password)
 
+    def as_list_item(self,ar):
+        return E.li(E.strong(self.username),' : ',
+          unicode(self),', ',
+          unicode(self.profile),', ',
+          E.strong(babel.LANGUAGE_DICT.get(self.language)))
+      
+    @classmethod
+    def get_by_username(cls,username,default=models.NOT_PROVIDED):
+        """
+        `User.get_by_username(x)` is equivalent to
+        `User.objects.get(username=x)` except that the text 
+        of the DoesNotExist exception is more useful.
+        """
+        try:
+            return cls.objects.get(username=username)
+        except cls.DoesNotExist,e:
+            if default is models.NOT_PROVIDED:
+                raise cls.DoesNotExist(
+                  "No %s with username %r" % (
+                      unicode(cls._meta.verbose_name),username))
+            return default
+
         
 
 
@@ -270,19 +295,19 @@ class MySettings(Users):
     
 class UsersOverview(Users):
     """
-    >>> from django.conf import settings
-    >>> settings.LINO.startup()
-    >>> print settings.LINO.modules.users.UsersOverview.to_rst()
+    >> from django.conf import settings
+    >> settings.SITE.startup()
+    >> print settings.SITE.modules.users.UsersOverview.to_rst()
     
     
     $ python manage.py shell
-    >>> from lino.modlib.users.models import UsersOverview as T; print T.to_rst()
+    >> from lino.modlib.users.models import UsersOverview as T; print T.to_rst()
     
     """
     column_names = 'username profile language'
     exclude = dict(profile='')
 
-if settings.LINO.user_model:
+if settings.SITE.user_model:
   
     class Authority(mixins.UserAuthored):
         """
@@ -299,7 +324,7 @@ if settings.LINO.user_model:
             
         #~ quick_search_fields = ('user__username','user__first_name','user__last_name')
         
-        authorized = models.ForeignKey(settings.LINO.user_model,
+        authorized = models.ForeignKey(settings.SITE.user_model,
             help_text=_("""\
 The user who gets authority to act in your name."""))
 
@@ -307,7 +332,7 @@ The user who gets authority to act in your name."""))
 
         @dd.chooser()
         def authorized_choices(cls,user):
-            qs = settings.LINO.user_model.objects.exclude(
+            qs = settings.SITE.user_model.objects.exclude(
                 profile=None)
                 #~ profile=dd.UserProfiles.blank_item) 20120829
             if user is not None:
