@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-## Copyright 2008-2012 Luc Saffre
+## Copyright 2008-2013 Luc Saffre
 ## This file is part of the Lino project.
 ## Lino is free software; you can redistribute it and/or modify 
 ## it under the terms of the GNU General Public License as published by
@@ -19,11 +19,11 @@ from django.db import models
 from django.conf import settings
 from django.utils.translation import ugettext as _
 
-from lino.core.modeltools import resolve_model
+from lino.core.dbutils import resolve_model
 from lino.utils.instantiator import Instantiator
 from lino.utils.babel import default_language
 from lino.utils.babel import babel_values
-from lino.utils.choicelists import Gender
+#~ from lino.utils.choicelists import Gender
 #~ from lino.utils.perms import UserLevels
 #~ from lino.core.perms import UserProfiles
 from lino.utils import dblogger
@@ -31,7 +31,7 @@ from lino.utils import Cycler
 
 from lino.sandbox.contacts import models as contacts
 
-print 20120225, 'settings.FIXTURE_DIRS is', settings.FIXTURE_DIRS
+#~ print 20120225, 'settings.FIXTURE_DIRS is', settings.FIXTURE_DIRS
 
 dblogger.info("Imported contacts demo fixture")
 
@@ -48,13 +48,13 @@ Person = contacts.Person
 User = contacts.User
 City = resolve_model('countries.City')
 
-if not settings.LINO.abstract_address:
+if not settings.SITE.abstract_address:
     Address = contacts.Address
     address = Instantiator(Address,"country zip_code city:name street street_no").build
 
 
 def company(name,country_id,zip_code,city,street,street_no):
-    if settings.LINO.abstract_address:
+    if settings.SITE.abstract_address:
         city = City.objects.get(name=city)
         yield Company(name=name,country_id=country_id,zip_code=zip_code,
           city=city,street=street,street_no=street_no)
@@ -65,7 +65,7 @@ def company(name,country_id,zip_code,city,street,street_no):
         yield com
 
 def person(first_name,last_name,country_id=None,zip_code='',city=None,**kw):
-    if settings.LINO.abstract_address:
+    if settings.SITE.abstract_address:
         if city is not None:
             city = City.objects.get(name=city)
         yield Person(first_name=first_name,last_name=last_name,
@@ -114,18 +114,18 @@ def objects():
     
     #~ yield person(u'Luc',  u'Saffre', gender=Gender.male)
     
-    yield person(u'Andreas',  u'Arens', 'BE','4700','Eupen',  gender=Gender.male)
-    yield person(u'Annette',  u'Arens','BE','4700','Eupen',  gender=Gender.female)
-    yield person(u'Hans',     u'Altenberg','BE','4700','Eupen',  gender=Gender.male)
-    yield person(u'Alfons',   u'Ausdemwald','BE','4700','Eupen',  gender=Gender.male)
-    yield person(u'Laurent',  u'Bastiaensen','BE','4700','Eupen',  gender=Gender.male)
-    yield person(u'Charlotte',  u'Collard','BE','4700','Eupen',  gender=Gender.female)
-    yield person(u'Ulrike',  u'Charlier','BE','4700','Eupen',  gender=Gender.female)
-    yield person(u'Marc',  u'Chantraine','BE','4700','Eupen',  gender=Gender.male)
-    yield person(u'Daniel',   u'Dericum','BE','4700','Eupen',  gender=Gender.male)
-    yield person(u'Dorothée', u'Demeulenaere','BE','4700','Eupen',  gender=Gender.female)
-    yield person(u'Berta',    u'Ernst','BE','4700','Eupen',  gender=Gender.female)
-    yield person(u'Bernd',    u'Evertz','BE','4700','Eupen',  gender=Gender.male)
+    yield person(u'Andreas',  u'Arens', 'BE','4700','Eupen',  gender=mixins.Genders.male)
+    yield person(u'Annette',  u'Arens','BE','4700','Eupen',  gender=mixins.Genders.female)
+    yield person(u'Hans',     u'Altenberg','BE','4700','Eupen',  gender=mixins.Genders.male)
+    yield person(u'Alfons',   u'Ausdemwald','BE','4700','Eupen',  gender=mixins.Genders.male)
+    yield person(u'Laurent',  u'Bastiaensen','BE','4700','Eupen',  gender=mixins.Genders.male)
+    yield person(u'Charlotte',  u'Collard','BE','4700','Eupen',  gender=mixins.Genders.female)
+    yield person(u'Ulrike',  u'Charlier','BE','4700','Eupen',  gender=mixins.Genders.female)
+    yield person(u'Marc',  u'Chantraine','BE','4700','Eupen',  gender=mixins.Genders.male)
+    yield person(u'Daniel',   u'Dericum','BE','4700','Eupen',  gender=mixins.Genders.male)
+    yield person(u'Dorothée', u'Demeulenaere','BE','4700','Eupen',  gender=mixins.Genders.female)
+    yield person(u'Berta',    u'Ernst','BE','4700','Eupen',  gender=mixins.Genders.female)
+    yield person(u'Bernd',    u'Evertz','BE','4700','Eupen',  gender=mixins.Genders.male)
     yield person(u'Eberhart', u'Evers','BE','4700','Eupen',  gender=Gender.male)
     yield person(u'Daniel',   u'Emonts','BE','4700','Eupen',  gender=Gender.male)
     yield person(u'Edgar',    u'Engels','BE','4700','Eupen',  gender=Gender.male)
@@ -296,7 +296,7 @@ Weserstraße
     
     streets_of_eupen = [ line.strip() for line in s.splitlines() if len(line.strip()) > 0 ]
     
-    if settings.LINO.abstract_address:
+    if settings.SITE.abstract_address:
     
         nr = 1
         #~ CITIES = Cycler(City.objects.all())
