@@ -15,12 +15,6 @@
 """
 
 
-:func:`iif` (inline ``if``)
----------------------------
-
->>> iif(1>2,'yes','no')
-'no'
-
 :func:`str2hex` and :func:`hex2str`
 -----------------------------------
 
@@ -44,6 +38,9 @@ This is a test
 >>> print join_words('This','is','','another','test')
 This is another test
 
+>>> print join_words(None,None,None,'Third','test')
+Third test
+
 
 """
 
@@ -51,32 +48,23 @@ This is another test
 #~ logger = logging.getLogger(__name__)
 
 
-import os, sys, locale, types, datetime
+import os, sys, locale, types, time
+import datetime
+import re
+import fnmatch
 from dateutil import parser as dateparser
 from decimal import Decimal
 import stat
 
-#~ import lino
+# encapsulate where they come from:
+
+from djangosite.utils import AttrDict, iif, ispure, assert_pure, confirm
+from djangosite.utils import rstgen
+from djangosite.utils import sphinxconf
+from north.utils import Cycler
+from .code import codefiles, codetime
 
-def confirm(prompt=None):
-    """
-    Ask for user confirmation from the console.
-    """
-    while True:
-        ln = raw_input(prompt)
-        if ln.lower() in ('y','j','o'):
-            return True
-        if ln.lower() == 'n':
-            return False
-        print "Please anwer Y or N"
 
-def iif(l,y,f): 
-    """
-    "Inline If" : an ``if`` statement as a function.
-    """
-    if l: return y 
-    return f
-    
 def isiterable(x):
     "Returns `True` if the specified object is iterable."
     try:
@@ -86,23 +74,6 @@ def isiterable(x):
     return True
     
     
-def ispure(s):
-    """Returns `True` if the specified string `s` is either a unicode 
-    string or contains only ASCII characters."""
-    if s is None: return True 
-    if type(s) == types.UnicodeType:
-        return True
-    if type(s) == types.StringType:
-        try:
-            s.decode('ascii')
-        except UnicodeDecodeError,e:
-            return False
-        return True
-    return False
-
-def assert_pure(s):
-    assert ispure(s), "%r: not pure" % s
-     
 
 def join_words(*words):
     """
@@ -117,11 +88,46 @@ def d2iso(d):
     return "%04d-%02d-%02d" % (d.year, d.month, d.day)
 
 def i2d(i):
+    """
+    Convert `int` to `date`. Examples:
+    
+    >>> i2d(20121224)
+    datetime.date(2012, 12, 24)
+    
+    """
     d = dateparser.parse(str(i))
     d = datetime.date(d.year,d.month,d.day)
     #print i, "->", v
     return d
     
+def i2t(s):
+    """
+    Convert `int` to `time`. Examples:
+    
+    >>> i2t(815)
+    datetime.time(8, 15)
+    
+    >>> i2t(1230)
+    datetime.time(12, 30)
+    
+    >>> i2t(12)
+    datetime.time(12, 0)
+    
+    >>> i2t(1)
+    datetime.time(1, 0)
+    
+    """
+    s = str(s)
+    if len(s) == 4:
+        return datetime.time(int(s[:2]),int(s[2:]))
+    if len(s) == 3:
+        return datetime.time(int(s[:1]),int(s[1:]))
+    if len(s) <= 2:
+        return datetime.time(int(s),0)
+    raise ValueError(s)
+
+    
+    
 def get_class_attr(cl,name):
     value = getattr(cl,name,None)
     if value is not None:
@@ -208,27 +214,6 @@ curry = lambda func, *args, **kw:\
                  
     
 
-def codetime():
-    """
-    Return the modification time of the youngest source code in memory.
-    Used by :mod:`lino.ui.extjs3.ext_ui` to avoid generating lino.js files if not necessary.
-    Inspired by the code_changed() function in django.utils.autoreload.
-    """
-    code_mtime = None
-    for filename in filter(lambda v: v, map(lambda m: getattr(m, "__file__", None), sys.modules.values())):
-        if filename.endswith(".pyc") or filename.endswith(".pyo"):
-            filename = filename[:-1]
-        if filename.endswith("$py.class"):
-            filename = filename[:-9] + ".py"
-        if not os.path.exists(filename):
-            continue # File might be in an egg, so it can't be reloaded.
-        stat = os.stat(filename)
-        mtime = stat.st_mtime
-        #~ print filename, time.ctime(mtime)
-        if code_mtime is None or code_mtime < mtime:
-            code_mtime = mtime
-    return code_mtime
-    
     
 class IncompleteDate:
     """
@@ -322,108 +307,6 @@ class IncompleteDate:
             self.day or 1)
         
 
-class AttrDict(dict):
-    """
-    Usage example:
-    
-    >>> a = AttrDict()
-    >>> a.define('foo',1)
-    >>> a.define('bar','baz',2)
-    >>> print a
-    {'foo': 1, 'bar': {'baz': 2}}
-    >>> print a.foo
-    1
-    >>> print a.bar.baz
-    2
-    >>> print a.resolve('bar.baz')
-    2
-    >>> print a.bar
-    {'baz': 2}
-    
-    """
-  
-    def __getattr__(self, name):
-        return self[name]
-        
-    def define2(self,name,value):
-        return self.define(*name.split('.')+[value])
-        
-    def define(self,*args):
-        "args must be a series of names followed by the value"
-        assert len(args) >= 2
-        d = s = self
-        for n in args[:-2]:
-            d = s.get(n,None)
-            if d is None:
-                d = AttrDict()
-                s[n] = d
-            s = d
-        oldvalue = d.get(args[-2],None)
-        #~ if oldvalue is not None:
-            #~ print 20120217, "Overriding %s from %r to %r" % (
-              #~ '.'.join(args[:-1]),
-              #~ oldvalue,
-              #~ args[-1]
-              #~ )
-        d[args[-2]] = args[-1]
-        return oldvalue
-    
-    def resolve(self,name,default=None):
-        """
-        return an attribute with dotted name
-        """
-        o = self
-        for part in name.split('.'):
-            o = getattr(o,part,default)
-            # o = o.__getattr__(part)
-        return o
-        
-
-class Cycler:
-    """
-    Turns a list of items into an endless loop.
-    Useful when generating demo fixtures.
-    
-    >>> def myfunc():
-    ...     yield "a"
-    ...     yield "b"
-    ...     yield "c"
-    
-    >>> c = Cycler(myfunc())
-    >>> s = ""
-    >>> for i in range(10):
-    ...     s += c.pop()
-    >>> print s
-    abcabcabca
-    
-    """
-    def __init__(self,*args):
-        if len(args) == 0:
-            raise ValueError()
-        elif len(args) == 1:
-            self.items = list(args[0])
-        else:
-            self.items = args
-        self.current = 0
-        
-    def pop(self):
-        if len(self.items) == 0: return None
-        item = self.items[self.current]
-        self.current += 1
-        if self.current >= len(self.items):
-            self.current = 0
-        if isinstance(item,Cycler):
-            return item.pop()
-        return item
-        
-    def __len__(self):
-        return len(self.items)
-        
-    def reset(self):
-        self.current = 0
-        
-
-
 
 #~ class Warning(Exception): 
     #~ """
@@ -495,6 +378,47 @@ def unicode_string(x):
     # Python 2.6.6 said "Error in formatting: encode() takes no keyword arguments"
     #~ return unicode(x).encode(errors='backslashreplace')
     
+    
+ONE_DAY = datetime.timedelta(days=1)
+
+def workdays(start,end):
+    """
+    Return the number of workdays (Monday to Friday) between the given 
+    two dates. Is not aware of holidays. 
+    
+    Both dates start and end are included. For example if you 
+    specify a Monday as start and Monday of the following 
+    week as end, then you get 6 (not 5).
+    
+    Examples:
+    >>> examples = [
+    ...   (20121130,20121201,1),
+    ...   (20121130,20121224,17),
+    ...   (20121130,20121130,1),
+    ...   (20121201,20121201,0),
+    ...   (20121201,20121202,0),
+    ...   (20121201,20121203,1),
+    ...   (20121130,20121207,6),
+    ... ]
+    >>> for start,end,expected in examples:
+    ...     a = i2d(start)
+    ...     b = i2d(end)
+    ...     if workdays(a,b) != expected:
+    ...        print "Got %d instead of %d for (%s,%s)" % (workdays(a,b),expected,a,b)
+    
+    """
+    #~ for d in range(start,end,ONE_DAY):
+        #~ if d.isoweekday() <= 5:
+            #~ n += 1
+    n = 0
+    d = start
+    while d <= end:
+        if d.isoweekday() <= 5:
+            n += 1
+        d += ONE_DAY
+    return n
+    
+    
 
 
 def _test():
